c===================================================================
c@***s*  HIRS/binit.f
c*
c* NAME
c*  binit.f
c*
c* LOCATION
c*  .../hirs/flib/binit.f
c*
c* PURPOSE
c*  Finds lat and lon index given resolution and lat,lon location.
c*
c* DESCRIPTION
c*  Finds lat and lon index given resolution and lat,lon location.
c*
c* AUTHOR
c*  Darren Jackson CIRES/ETL
c*
c* CREATION DATE
c*  Apr 2002
c*
c* COPYRIGHT
c*  THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC DOMAIN AND
c*  THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE.  THEY ARE FURNISHED "AS IS." THE 
c*  AUTHORS, THE UNITED STATES GOVERNMENT, ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES, 
c*  AND AGENTS MAKE NO WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE 
c*  SOFTWARE AND DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
c*  THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL SUPPORT 
c*  TO USERS.
c*
c* MODIFICATION HISTORY
c*  Apr 2010 - D. Wunder put in robodoc format
c*
c* INPUTS
c*  res -  resolution in degrees (1, 2, 2.5, 5 are best values)
c*  lonctr - 0...centered on GM, 1...edge on GM
c*  latctr - 0...centered on EQ, 1...edge on EQ
c*  lon - 0 to 360 degrees eastward (starting point is can be chosen)
c*  lat - -90 to  90 degrees northward
c*
c* OUTPUTS
c*  ii - longitude index starting from GM and going eastward.
c*       lonctr=0 : ii=1 for box center on GM
c*       lonctr=1 : ii=1 for box with left edge on GM
c*  jj -  latitude index starting from SP (center or edge) and going northward
c*       latctr=0 : jj=1 for box center on EQ (and centered on poles)
c*       latctr=1 : jj=1 for box with edge on EQ (and edges on poles)
c*
c* LANGUAGE
c*  Fortran 
c*
c@*****
c=====================================================================

      subroutine binit(res,lonctr,latctr,xlon,xlat,ii,jj)

      implicit none

      real res,xlat,xlon
      integer ii,jj,lonctr,latctr

c* Longitude edge case
      if(lonctr .eq. 1) then
         ii=ifix(xlon/res)+1
         if(xlon .eq. 360.) ii=1
c* Longitude centered case
      elseif(lonctr .eq. 0) then
         ii=ifix((xlon+(res/2.))/res)+1
         if(xlon .ge. 360.-res/2.) ii=1
      else
         write(*,*) 'lonctr not equal to 0 or 1'
         stop
      endif
c* Latitude edge case
      if(latctr .eq. 1) then
         jj=ifix((xlat+90.)/res)+1
         if(xlat .eq. 90.) jj=ifix((xlat+90.)/res)
c* Latitude centered case
      elseif(latctr .eq. 0) then
         jj=ifix(((xlat+90.+res/2.))/res)+1
      else
         write(*,*) 'latctr not equal to 0 or 1'
         stop
      endif

      return
      end
