c====================================================================================
c@***h*  HIRS/julian2.f
c*
c* NAME
c*  julian2.f
c*
c* LOCATION
c*  .../hirs/flib/julian2.f
c*
c* PURPOSE
c*  Finds two digit month/day from julian day/yr
c*
c* DESCRIPTION
c*  Finds two digit month/day from julian day/yr
c*
c* AUTHOR
c*  Darren Jackson
c*
c* CREATION DATE
c*  Nov 2004
c*
c* COPYRIGHT
c*  THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC DOMAIN AND
c*  THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE.  THEY ARE FURNISHED "AS IS." THE 
c*  AUTHORS, THE UNITED STATES GOVERNMENT, ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES, 
c*  AND AGENTS MAKE NO WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE 
c*  SOFTWARE AND DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
c*  THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL SUPPORT 
c*  TO USERS.
c*
c* MODIFICATION HISTORY
c*  May 2010 - D. Wunder put in robodoc format
c*
c* INPUTS
c*   jd .... julian day
c*   yr .... year
c*
c* OUTPUTS
c*   mn .... month
c    dy .... day
c*
c* LANGUAGE
c*  Fortran 
c*
c@*****
c=========================================================================
      subroutine julian2(jd,yr,mn,dy)

      integer yr,mn,dy,jd
      integer leap,cumulday(12,2)

      data cumulday/31,59,90,120,151,181,212,243,273,304,334,365,
     .              31,60,91,121,152,182,213,244,274,305,335,366/
c
c*     is it leap year?
c
      IF ((MOD(YR,4) .EQ. 0 .AND. MOD(YR,100) .NE. 0)
     .     .OR. MOD(YR,400) .EQ. 0 ) THEN
         LEAP = 2
      else
         leap = 1
      endif
c
c*  Julian day 
c
      do m=1,12
         jd_tmp=cumulday(m,leap)
         if(jd_tmp .ge. jd) then
            mn=m
            if(mn.eq.1) then
               dy=jd
            else
               dy=(cumulday(m,leap)-cumulday(m-1,leap))-(jd_tmp-jd)
            endif
            goto 99
         endif
      enddo
 99   return
      end
