#! /bin/csh
#--------------------------------------------------------------------------------
#@***p* HIRS/runlimbcor_m.csh
#
# NAME
#   runlimbcor_m.csh
#
# LOCATION
#   .../hirs/lcproc/work/runlimbcor_m.csh
#
# PURPOSE
#   Perform limb-correction for Metop-A HIRS.
#
# DESCRIPTION
#   Perform limb-correction for Metop-A HIRS using the method developed by 
# Jackson, D. L., D. P. Wylie, and J. J. Bates (2003), The HIRS Pathfinder 
# radiance data set (1979-2001), paper presented at 12th Conference on 
# Satellite Meteorology and Oceanography, Long Beach, California, February 
# 10-13, 2003.
#
# AUTHOR
#   L. Shi  
#
# CREATION DATE
#   Sep 2008
#
# COPYRIGHT
#   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC DOMAIN AND
#   THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE.  THEY ARE FURNISHED "AS IS." THE 
#   AUTHORS, THE UNITED STATES GOVERNMENT, ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES, 
#   AND AGENTS MAKE NO WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE 
#   SOFTWARE AND DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
#   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL SUPPORT 
#   TO USERS.
#
# MODIFICATION HISTORY
#   May 2010 - D. Wunder put in robodoc format
#
# INPUTS
#   SATID = satellite id
#   YY    = two digit year
#
# OUTPUTS
#   HIRS.$SATID.Y$YY.*.LC = limb-corrected HIRS data
#
# TODO
#   n/a
#
# LANGUAGE
#   C-Shell
#
#@*****
#---------------------------------------------------------------------------------


if ($#argv <= 1) then
  echo "Usage: $0 satellite_id 2-digit-year (e.g. runlimbcor_m.csh M02 09)"
  exit 0
endif

set SATID = $argv[1]
set YY = $argv[2]

set DIRCOEF = ${hirs_lcproc_dir}/limbcoef/
set DIRDATA = ${hirs_DAT_DIR}/cs_data
set DIROUT = ${hirs_lc_dir}/LC_$SATID
set DIRWORK = ${hirs_lcproc_dir}/work

cd $DIRDATA
foreach i ( `ls HIRS.$SATID.Y$YY.*.CS` )
echo $i
cd $DIRDATA
cp $i $DIRWORK
cd $DIRWORK

rm param
set SATNUM = `echo $SATID | cut -c2-3`
set YEAR = `echo $i | cut -c11-12`
set DAY = `echo $i | cut -c15-17`

echo $SATNUM | cat >> param
echo $YEAR | cat >> param
echo $DAY | cat >> param
echo y | cat >> param
echo $DIRCOEF | cat >> param
echo y | cat >> param
echo $DIRWORK | cat >> param
echo 2 | cat >> param

${hirs_lcproc_dir}/srcnew/read_scanline_v3 < param
cp read_scanline_v2.dat $DIROUT/HIRS.$SATID.Y$YEAR.D$DAY.LC
rm $DIRWORK/$i

end

exit 1
