#! /bin/csh
#--------------------------------------------------------------------------------
#@***p* HIRS/hirslc2nc_m.csh
#
# NAME
#   hirslc2nc_m.csh
#
# LOCATION
#   .../hirs/scripts/2nc/hirslc2nc_m.csh
#
# PURPOSE
#   Convert HIRS limb-corrected Tb data to NetCDF format
#
# DESCRIPTION
#   Convert HIRS limb-corrected Tb data to NetCDF format
#
# AUTHOR
#   L. Shi
#
# CREATION DATE
#   Aug 2005
#
# COPYRIGHT
#   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC DOMAIN AND
#   THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE.  THEY ARE FURNISHED "AS IS." THE 
#   AUTHORS, THE UNITED STATES GOVERNMENT, ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES, 
#   AND AGENTS MAKE NO WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE 
#   SOFTWARE AND DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
#   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL SUPPORT 
#   TO USERS.
#
# MODIFICATION HISTORY
#   May 2010 - D. Wunder put in robodoc format
#
# INPUTS
#   SATNUM = Satellite id
#   SATID  = Satellite id
#   YY     = 2 digit year
#
# OUTPUTS
#   HIRS.$SATID.Y$YEAR.D$DAY.LC .... limb corrected Tb data
#
# EXTERNALS
#   clearlc2nc.c
#
# TODO
#   n/a
#
# LANGUAGE
#   C-Shell
#
#@*****
#---------------------------------------------------------------------------------

if ($#argv <= 1) then
  echo "Usage: $0 satellite_id 2-digit-year (e.g. tbdaily.csh M02 09)"
  exit 0
endif
set SATNUM = $argv[1]
set SATID = $argv[1]
set YY = $argv[2]

#cd /net/crystal/home/lshi
cd $hirs_DAT_DIR
rm -rf tmphirscs2nc$SATNUM
mkdir tmphirscs2nc$SATNUM
#set WORK = /net/crystal/home/lshi/tmphirscs2nc$SATNUM
set WORK = $hirs_DAT_DIR/tmphirscs2nc$SATNUM
#set DIRIN = /net/crystal/san2/hirslc/LC_$SATID
set DIRIN = $hirs_lc_dir/LC_$SATID
#set DIROUT = /net/crystal/san3/raid3a/hirslc_nc/LC_$SATID
set DIROUT = $hirs_lcnc_dir/LC_$SATID

#cp /net/crystal/home/lshi/2nc/clearlc2nc $WORK
cp $hirs_SCRIPT_DIR/2nc/clearlc2nc $WORK

cd $DIRIN
echo $DIRIN
foreach FILE (`ls HIRS.$SATID.Y$YY*.LC`)
  echo $FILE
  cp $FILE $WORK
  cd $WORK

  set YEAR = `echo $FILE | cut -c11-12`
  set DAY = `echo $FILE | cut -c15-17`

  $WORK/clearlc2nc HIRS.$SATID.Y$YEAR.D$DAY.LC

  mv $WORK/hirsbt_lc.nc $DIROUT/HIRS.$SATID.Y$YEAR.D$DAY.nc
  rm $WORK/$FILE

  cd $DIRIN
end

rm -rf $WORK
exit 1
