#!/bin/csh
#--------------------------------------------------------------------------------
#@***p* HIRS/calday2date.csh
#
# NAME
#   calday2data.csh
#
# LOCATION
#   /hirsoperation/clearsky4/scripts/calday2data.csh
#
# PURPOSE
#   Determines if the input of year (4 digit) and julian day is a leap year,
#   and then finds the month number and day number
#
# DESCRIPTION
#   Determines if the input of year (4 digit) and julian day is a leap year,
#   and then finds the month number and day number
#
# AUTHOR
#   Darren Jackson CIRES/ETL
#
# CREATION DATE
#   April 2003
#
# COPYRIGHT
#   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC DOMAIN AND
#   THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE.  THEY ARE FURNISHED "AS IS." THE 
#   AUTHORS, THE UNITED STATES GOVERNMENT, ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES, 
#   AND AGENTS MAKE NO WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE 
#   SOFTWARE AND DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
#   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL SUPPORT 
#   TO USERS.
#
# MODIFICATION HISTORY
#   Mar 2010 - D. Wunder put in robodoc format
#
# INPUTS
#   year  = 4 digit year
#   jday  = 3 digit julian day
#
# OUTPUTS
#   mon   = 2 digit month
#   day   = 2 digit day
#   leap  = 1,0 (true,false)
#
# TODO
#   n/a
#
# LANGUAGE
#   C-Shell
#
#@*****
#---------------------------------------------------------------------------------
#
set year = $1
set jday = $2
#
# Cumulative day array (1 indicates leap year)
#
set cday0 = (0 31 59 90 120 151 181 212 243 273 304 334 365)
set cday1 = (0 31 60 91 121 152 182 213 244 274 305 335 366)
#
# Test for leap year: leap=1 indicates a leap year
#
if(($year % 4 == 0 && $year % 100 != 0) || $year % 400 == 0) then
  @ leap = 1
  if($jday < 1 || $jday > 366) exit 1
else
  @ leap = 0
  if($jday < 1 || $jday > 365) exit 1
endif
#
# Find month number, month name and day of month
#
@ mon = 1
while ($mon <= 12)
  @ mon2 = $mon ; @ mon2++
  if($leap == 1) then
    if($jday > $cday1[$mon] && $jday <= $cday1[$mon2]) then
      @ day = $jday - $cday1[$mon]
      echo $mon $day $leap
      exit 0
    endif
  else
    if($jday > $cday0[$mon] && $jday <= $cday0[$mon2]) then
      @ day = $jday - $cday0[$mon]
      echo $mon $day $leap
      exit 0
    endif
  endif
  @ mon++
end

end