#!/bin/csh
#--------------------------------------------------------------------------------
#@***p* HIRS/date2calday.csh
#
# NAME
#   date2calday.csh
#
# LOCATION
#   /hirsoperation/clearsky4/scripts/date2calday.csh
#
# PURPOSE
#  Finds calender (Julian) day number (1-366) for a given date
#
# DESCRIPTION
#  Finds calender (Julian) day number (1-366) for a given date
#
# AUTHOR
#   Darren Jackson CIRES/ETL  
#
# CREATION DATE
#   March 2002
#
# COPYRIGHT
#   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC DOMAIN AND
#   THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE.  THEY ARE FURNISHED "AS IS." THE 
#   AUTHORS, THE UNITED STATES GOVERNMENT, ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES, 
#   AND AGENTS MAKE NO WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE 
#   SOFTWARE AND DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
#   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL SUPPORT 
#   TO USERS.
#
# MODIFICATION HISTORY
#   Mar 2010 - D. Wunder put in robodoc format
#
# INPUTS
#   year  =    four digit year
#   month =    month number
#   day   =    day number
#
# OUTPUTS
#   calday =  number of calendar days (Julian day)
#
# TODO
#   n/a
#
# LANGUAGE
#   C-Shell
#
#@*****
#---------------------------------------------------------------------------------

set year   = $1
set month  = $2
set day    = $3
#
# Cumulative day array (1 indicates leap year)
#
set cday0 = (0 31 59 90 120 151 181 212 243 273 304 334 365)
set cday1 = (0 31 60 91 121 152 182 213 244 274 305 335 366)
#
# Test for leap year: leap=1 indicates a leap year
#
if(($year % 4 == 0 && $year % 100 != 0) || $year % 400 == 0) then
  @ leap = 1
  if($day < 1 || $day > 366) exit 1
else
  @ leap = 0
  if($day < 1 || $day > 365) exit 1
endif
#
# Find calender day
#
if($leap == 0) then
  @ calday = $cday0[$month] + $day
else
  @ calday = $cday1[$month] + $day
endif

echo $calday

