#!/bin/csh
#--------------------------------------------------------------------------------
#@***p* HIRS/date_to_julian69.csh
#
# NAME
#   date_to_julian69.csh
#
# LOCATION
#   /hirsoperation/clearsky4/scripts/date_to_julian69.csh
#
# PURPOSE
#  Script computes the number days from Jan. 1, 1969.
#
# DESCRIPTION
#  Script computes the number days from Jan. 1, 1969.
#  Error report status=1   ->  Input year less than 1969
#
# AUTHOR
#   Darren Jackson CIRES/ETL
#
# CREATION DATE
#   April 2003
#
# COPYRIGHT
#   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC DOMAIN AND
#   THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE.  THEY ARE FURNISHED "AS IS." THE 
#   AUTHORS, THE UNITED STATES GOVERNMENT, ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES, 
#   AND AGENTS MAKE NO WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE 
#   SOFTWARE AND DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
#   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL SUPPORT 
#   TO USERS.
#
# MODIFICATION HISTORY
#   Mar 2010 - D. Wunder put in robodoc format
#
# INPUTS
#   year  =    four digit year
#   month =    month number; if 1 and day > 31 then assume day = day of year
#   day   =    day number
#
# OUTPUTS
#   totdays =  number of days since Jan 1, 1969
#
# TODO
#   n/a
#
# LANGUAGE
#   C-Shell
#
#@*****
#---------------------------------------------------------------------------------

#
# INPUTS
set year  = $1      # four digit year
set month = $2      # month number; if 1 and day > 31 then assume day = day of year
set day   = $3      # day number

set cday0 = (0 31 59 90 120 151 181 212 243 273 304 334 365)
set cday1 = (0 31 60 91 121 152 182 213 244 274 305 335 366)

if($year < 1969) exit 1

@ yeardif  = $year - 1969
@ totdays  = $yeardif * 365
@ leapdays = $yeardif / 4
@ totdays  = $totdays + $leapdays

if($month > 1) then
  if(($year % 4 == 0 && $year % 100 != 0) || $year % 400 == 0) then
    @ totdays = $totdays + $cday1[$month] + $day    # leap year
  else
    @ totdays = $totdays + $cday0[$month] + $day    # not leap year
  endif
else
   @ totdays = $totdays + $day
endif

echo $totdays



