/* regiontb_m2.c */
/*
#--------------------------------------------------------------------------------
#@***p* HIRS/regiontb_m2.c
#
# NAME
#   regiontb_m2.c
#
# LOCATION
#   .../hirs/scripts/hirstb/region/regiontb_m2.c
#
# PURPOSE
#   Put togeter zonal monthly means from overlapping satellites
#
# DESCRIPTION
#   Put togeter zonal monthly means from overlapping satellites
#   The code doesn't work for 5 satellites or more
#
# AUTHOR
#   L. Shi
#
# CREATION DATE
#   Apr 2005
#
# COPYRIGHT
#   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC DOMAIN AND
#   THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE.  THEY ARE FURNISHED "AS IS." THE 
#   AUTHORS, THE UNITED STATES GOVERNMENT, ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES, 
#   AND AGENTS MAKE NO WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE 
#   SOFTWARE AND DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
#   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL SUPPORT 
#   TO USERS.
#
# MODIFICATION HISTORY
#   May 2010 - D. Wunder put in robodoc format
#
# INPUTS
#   HIRS.Y??.MG.TB.24 ... gridded monthly mean data from overlapping satellites
#
# OUTPUTS
#   allch.dat    ... zonal mean for channel 1-12
#   meansats.dat ... zonal mean for channel 12 only
#
# EXTERNALS
#   none
#
# TODO
#   n/a
#
# LANGUAGE
#   C
#
#@*****
#---------------------------------------------------------------------------------
*/

#include <stdio.h>
#include <malloc.h>
#include<stdlib.h>
#include <math.h>

#define nlon 144
#define nlat 72
#define nch 12
#define maxsatnum 4
#define month 12 /* 12 months */
#define maxch 156 /* 13 satellites (N5-N17,M2) x 12 channels */
#define minnum 5 /* minimum number of grid to calculate regional mean */
#define chprint 12 /* channel to print */

main(argc, argv)
     int argc;
     char **argv;
{
  FILE       *ifp[maxsatnum];                /* Input file pointer */
  FILE       *ofpallch,*ofpsats;

  int        i,j,k,m,n;
  int        year,sat[maxsatnum];
  float      t[nlat][nlon][nch][maxsatnum];
  float      gsum[nch],gmean[nch];
  int        gnum[nch];
  char       s[100];
  int        lat1,lat2,band,lon1,lon2;
  float      lat,lon;
  float      var[month][maxch];

  /* band: 1 = Central Pacific */
  band = 2;
  if (band == 1) {
    lat1 = -20;
    lat2 = 20;
    lon1 = 200;
    lon2 = 260;
  }
  if (band == 2) {
    lat1 = -30;
    lat2 = 30;
    lon1 = 0;
    lon2 = 360;
  }

  if (argc < 3)
    printf("%s%s%s\n", "Usage: ", argv[0], 
           " (individual sat monthly mean) f1 f2 ...");

  ofpallch = fopen("allch.dat","w");
  ofpsats = fopen("meansats.dat","w");

  for (n=0; n<argc-1; n++)
    ifp[n] = fopen(argv[n+1],"r");
  for (n=0; n<argc-1; n++)
    sscanf(argv[n+1],"%6c%2d",s,&sat[n]);
  sscanf(argv[1],"%10c%2d",s,&year);

  if (year > 50)
    year += 1900;
  else
    year += 2000;

  for (m=0; m<month; m++)
    for (k=0; k<maxch; k++)
      var[m][k] = 999.;

  for (m=0; m<month; m++) {
    for (n=0; n<argc-1; n++) {
      for (k=0; k<nch; k++)
        for (i=0; i<nlat; i++)
	  for (j=0; j<nlon; j++)
	    fscanf(ifp[n], "%f", &t[i][j][k][n]);
    }

    /* compute monthly lat/lon box regional mean */
    fprintf(ofpsats,"%7.2f,%2d,", year+m/12.,m+1);
    fprintf(ofpallch,"%7.2f %2d ", year+m/12.,m+1);
    for (n=0; n<argc-1; n++)
      for (k=0; k<nch; k++) {
        gsum[k] = 0.0;
        gnum[k] = 0;
        lat = -88.75 - 2.5;
        for (i=0; i<nlat; i++) {
	  lat = lat + 2.5;
	  lon = 1.25 - 2.5;
          for (j=0; j<nlon; j++) {
	    lon = lon + 2.5;
            if (t[i][j][k][n] < 400.0 && 
              lat < lat2 && lat > lat1 && lon < lon2 && lon > lon1) {
              gsum[k] = gsum[k] + t[i][j][k][n];
              gnum[k]++;
            }
	  }
        }

        if (gnum[k] >= minnum) {
          gmean[k] = gsum[k] / gnum[k];
	  if (sat[n] == 2)
	    var[m][(sat[n]+10)*nch+k] = gmean[k];
          if (sat[n] < 14 && sat[n] >=5)
            var[m][(sat[n]-5)*nch+k] = gmean[k];
          else
            var[m][(sat[n]-6)*nch+k] = gmean[k];
        }
      } /* end of k loop */

    for (k=chprint-1; k<maxch; k+=12) {
      if (var[m][k] < 400.0 && var[m][k] > 200.0)
        fprintf(ofpsats,"%6.2f,", var[m][k]);
      else
        fprintf(ofpsats,",");
    }
    fprintf(ofpsats,"\n");

    for (k=0; k<maxch; k++) {
      if (var[m][k] < 400.0 && var[m][k] > 200.0)
        fprintf(ofpallch,"%6.2f ", var[m][k]);
      else
        fprintf(ofpallch,"-99.99 ");
    }
    fprintf(ofpallch,"\n");

  } /* end of m loop */

  for (n=0; n<argc-1; n++)
    fclose(ifp[n]);
  fclose(ofpsats);
  fclose(ofpallch);
}
