#! /bin/csh
#--------------------------------------------------------------------------------
#@***p* HIRS/runregiontb.csh
#
# NAME
#   runregiontb.csh
#
# LOCATION
#   .../hirs/scripts/hirstb/region/runregiontb.csh
#
# PURPOSE
#   Calculate zonal monthly mean (currently set for 30N-30S)
#
# DESCRIPTION
#   Calculate zonal monthly mean (currently set for 30N-30S)
#
# AUTHOR
#   L. Shi
#
# CREATION DATE
#   Apr 2005
#
# COPYRIGHT
#   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC DOMAIN AND
#   THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE.  THEY ARE FURNISHED "AS IS." THE 
#   AUTHORS, THE UNITED STATES GOVERNMENT, ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES, 
#   AND AGENTS MAKE NO WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE 
#   SOFTWARE AND DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
#   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL SUPPORT 
#   TO USERS.
#
# MODIFICATION HISTORY
#   May 2010 - D. Wunder put in robodoc format
#
# INPUTS
#   year = two digit year
#
# OUTPUTS
#   HIRS.SATS.TB.ALLCH.24  ... zonal mean for channel 1-12
#   HIRS.SATS.TB.REGION.24 ... zonal mean for channel 12 only
#
# EXTERNALS
#   regiontb_m2.c
#
# TODO
#   n/a
#
# LANGUAGE
#   C-Shell
#
#@*****
#---------------------------------------------------------------------------------


set INDIR = ${hirs_DAT_DIR}/hirs_tb/tbgridmonthly
set OUTDIR = ${hirs_DAT_DIR}/hirs_tb/region
set WORKDIR = ${hirs_SCRIPT_DIR}/hirstb/region

set TIME = '24'
@ year = 78

\rm $OUTDIR/HIRS.*.TB.*.$TIME

while ($year <= 109)
  if ($year < 100) then
    @ yy = $year
  else
    @ y = $year - 100
    set yy = 0$y
  endif
  echo $yy
  cd $INDIR
  echo `ls HIRS.N*.Y$yy.MG.TB.$TIME HIRS.M*.Y$yy.MG.TB.$TIME`
  set FILES = ""
  set FILES = (`ls HIRS.N*.Y$yy.MG.TB.$TIME HIRS.M*.Y$yy.MG.TB.$TIME`)
  if ( $FILES != "") then  
    cp $FILES $WORKDIR
    cd $WORKDIR
    $WORKDIR/regiontb_m2 $FILES
    cat allch.dat >> $OUTDIR/HIRS.SATS.TB.ALLCH.$TIME
    cat meansats.dat >> $OUTDIR/HIRS.SATS.TB.REGION.$TIME
    rm $FILES
  endif

  @ year++
end

exit 1
