#! /bin/csh
#--------------------------------------------------------------------------------
#@***p* HIRS/tbdaily2000.csh
#
# NAME
#   tbdaily2000.csh
#
# LOCATION
#   .../hirs/scripts/hirstb/tb/tbdaily2000.csh
#
# PURPOSE
#   Map daily swath HIRS channel data to global grid. 
#
# DESCRIPTION
#   Map daily swath HIRS channel data to global grid. Process one year data.
#   Works for Metop as well as NOAA satellites.
#   Works for year 2000 and later only.
#
# AUTHOR
#   L, Shi
#
# CREATION DATE
#   April 2005
#
# COPYRIGHT
#   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC DOMAIN AND
#   THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE.  THEY ARE FURNISHED "AS IS." THE 
#   AUTHORS, THE UNITED STATES GOVERNMENT, ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES, 
#   AND AGENTS MAKE NO WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE 
#   SOFTWARE AND DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
#   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL SUPPORT 
#   TO USERS.
#
# MODIFICATION HISTORY
#   May 2010 - D. Wunder put in robodoc format
#
# INPUTS
#   SATID = satellite ID
#   YY    = two digit year
#
# OUTPUTS
#   HIRS.$SATID.Y$YY.TB24 ... 24-hour daily gridded data.
#
# EXTERNALS
#   tbdaily24.c
#
# TODO
#   n/a
#
# LANGUAGE
#   C-Shell
#
#@*****
#---------------------------------------------------------------------------------


if ($#argv <= 1) then
  echo "Usage: $0 satellite_ID 2-digit-year (e.g., tbdaily.csh M02 08)"
  exit 0
endif
set SATID = $argv[1]
set YY = $argv[2]

set DIRDATA = ${hirs_DAT_DIR}/hirs_lc/LC_$SATID
set OUTDIR = ${hirs_DAT_DIR}/hirs_tb/tbgriddaily
set WORKDIR = ${hirs_SCRIPT_DIR}/hirstb/tb

set hour = (24)
foreach TIME ($hour)

cd $DIRDATA
\rm *.TB$TIME
foreach i ( `ls HIRS.$SATID.Y$YY.*.LC` )
  echo $i

  set SATNUM = `echo $i | cut -c7-8`
  set YEAR = `echo $i | cut -c11-12`
  set DAY = `echo $i | cut -c15-17`

#  if ($YEAR > 70) then
#    @ YYYY = 1900 + $YEAR
#  else
#    @ YYYY = 2000 + $YEAR
#  endif
  echo $SATNUM 20$YEAR $DAY
  echo $SATNUM 20$YEAR $DAY | cat >> HIRS.$SATID.Y$YEAR.TB$TIME
  $WORKDIR/tbdaily$TIME $i
  cat tgrid.dat >> HIRS.$SATID.Y$YEAR.TB$TIME

end

mv HIRS.*.TB$TIME $OUTDIR

end
rm $DIRDATA/tgrid.dat

exit 1
