/* tbdaily.c */
/*
#--------------------------------------------------------------------------------
#@***p* HIRS/tbdaily24.c
#
# NAME
#   tbdaily24.c
#
# LOCATION
#   .../hirs/scripts/hirstb/tb/tbdaily24.c
#
# PURPOSE
#   Daily gridding of HIRS ch1-12 from clear-sky swath data 
#
# DESCRIPTION
#   Daily gridding of HIRS ch1-12 from clear-sky swath data
#   After compiling, manually copy the executable to tbdaily24
#
# AUTHOR
#   L. Shi
#
# CREATION DATE
#   Apr 2005
#
# COPYRIGHT
#   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC DOMAIN AND
#   THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE.  THEY ARE FURNISHED "AS IS." THE 
#   AUTHORS, THE UNITED STATES GOVERNMENT, ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES, 
#   AND AGENTS MAKE NO WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE 
#   SOFTWARE AND DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
#   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL SUPPORT 
#   TO USERS.
#
# MODIFICATION HISTORY
#   May 2010 - D. Wunder put in robodoc format
#
# INPUTS
#   HIRS.$SATID.Y$yy.D$ddd.LC ... Limb corrected HIRS channel Tb
#
# OUTPUTS
#   tgrid.dat ... gridded data
#
# EXTERNALS
#   none
#
# TODO
#   n/a
#
# LANGUAGE
#   C
#
#@*****
#---------------------------------------------------------------------------------
*/


#include <stdio.h>
#include <malloc.h>
#include<stdlib.h>
#include <math.h>

#define nlon 144
#define nlat 72
#define total 160000
#define ch 12

main(argc, argv)
     int argc;
     char **argv;
{
  FILE       *ifp;                /* Input file pointer                */
  FILE       *ofp;
  int        n,i,j,k;
  float      tch,tlc[ch][total];
  int        missing,num,count;
  char       s[100];
  float sec[total],lon[total],lat[total],zen,alt;
  int line,posi;
  int i1;
  float f1,f2;
  float latgrid,longrid,tgrid[nlat][nlon][12];
  int test,secb,sece;

  /* 3h=10800s;6h=21600;9h=32400;12h=43200;
     15h=54000;18h=64800;21h=75600;24h=86400s */
  secb = 0;
  sece = 86400;

  ifp = fopen(argv[1],"r");
  ofp = fopen("tgrid.dat","w");

  count = 0;
  for (n=0; n<total; n++) {
    test=fscanf(ifp, "%s%f%f%f%f%f%d%d", 
       s,&sec[n],&lon[n],&lat[n],&zen,&alt,&line,&posi);
    if (test == -1)
      goto endofdata;
    for (k=0; k<ch; k++) {
      fscanf(ifp, "%s%d%f%f", s,&i1,&tch,&tlc[k][n]);
    }
    for (k=0; k<7; k++)
      fscanf(ifp, "%s%d%f%f", s,&i1,&f1,&f2);
    fscanf(ifp, "%s%d%f", s,&i1,&f1);
    count++;
  }
 endofdata: printf("count=%d\n", count);

  for (i=0; i<nlat; i++)
    for (j=0; j<nlon; j++)
      for (k=0; k<ch; k++)
	tgrid[i][j][k] = 0.0;

    latgrid = -88.75-2.5;
    for (i=0; i<nlat; i++) {
      latgrid = latgrid + 2.5;
      longrid = 1.25-2.5;
      for (j=0; j<nlon; j++) {
	longrid = longrid + 2.5;
        num=0;
	for (n=0; n<count; n++) {
	  if(fabs(lat[n]-latgrid)<1.25 && fabs(lon[n]-longrid)<1.25
            && sec[n] >= secb && sec[n] < sece) {
	    for (k=0; k<12; k++) {
	      tgrid[i][j][k] = tgrid[i][j][k] + tlc[k][n];
	    }
	    num++;
	  }
	}
	if (num > 0)
	  for (k=0; k<12; k++)
	    tgrid[i][j][k] = tgrid[i][j][k] / num;
	else
	  for (k=0; k<ch; k++)
	    tgrid[i][j][k] = 999;
      } /* end j loop */
    } /* end i loop */

    for (k=0; k<ch; k++)
      for (i=0; i<nlat; i++) {
      for (j=0; j<nlon; j++)
	fprintf(ofp," %6.2f", tgrid[i][j][k]);
      fprintf(ofp,"\n");
    }

    fclose(ifp);
    fclose(ofp);
}

