#! /bin/csh
#--------------------------------------------------------------------------------
#@***p* HIRS/tbmonthly.csh
#
# NAME
#   tbmonthly.csh
#
# LOCATION
#   .../hirs/scripts/hirstb/tb/tbmonthly.csh
#
# PURPOSE
#   Calculate monthly from daily data of one satellite
#
# DESCRIPTION
#   Calculate monthly from daily data of one satellite
#   Works for Metop as well as NOAA satellites
#
# AUTHOR
#   L. Shi
#
# CREATION DATE
#   Apr 2005
#
# COPYRIGHT
#   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC DOMAIN AND
#   THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE.  THEY ARE FURNISHED "AS IS." THE 
#   AUTHORS, THE UNITED STATES GOVERNMENT, ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES, 
#   AND AGENTS MAKE NO WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE 
#   SOFTWARE AND DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
#   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL SUPPORT 
#   TO USERS.
#
# MODIFICATION HISTORY
#   May 2010 - D. Wunder put in robodoc format
#
# INPUTS
#   SATID = satellite ID
#   YY    = two digit year
#
# OUTPUTS
#   HIRS.$SATID.MS.TB.24     ... time series of global mean Tb
#   HIRS.$SATID.Y??.MG.TB.24 ... gridded monthly mean Tb
#
# EXTERNALS
#   tbmonthly.c
#
# TODO
#   n/a
#
# LANGUAGE
#   C-Shell
#
#@*****
#---------------------------------------------------------------------------------


if ($#argv <= 1) then
  echo "Usage: $0 satellite_ID 2-digit-year (e.g., tbmonthly.csh M02 08"
  exit 0
endif
set SATID = $argv[1]
set YY = $argv[2]

set DIRDATA = ${hirs_DAT_DIR}/hirs_tb/tbgriddaily
set OUTDIR = ${hirs_DAT_DIR}/hirs_tb/tbgridmonthly
set WORKDIR = ${hirs_SCRIPT_DIR}/hirstb/tb

set hour = (24)
foreach TIME ($hour)

cd $DIRDATA
\rm HIRS.N*.MS.TB.$TIME
\rm HIRS.N*.MG.TB.$TIME

foreach i ( `ls HIRS.$SATID.Y$YY.TB$TIME` )
echo $i

set YEAR = `echo $i | cut -c11-12`

$WORKDIR/tbmonthly $i
cat gmean.dat >> HIRS.$SATID.MS.TB.$TIME
cat mean.dat >> HIRS.$SATID.Y$YEAR.MG.TB.$TIME

end

mv HIRS.$SATID.MS.TB.$TIME $OUTDIR
mv HIRS.$SATID.Y*.MG.TB.$TIME $OUTDIR
rm gmean.dat
rm mean.dat

end

exit 1
