// wcalib.c
// Intersatellite calibration for Metop HIRS
// run example: a.out HIRS.M02.Y07.D215.LC
/*
#--------------------------------------------------------------------------------
#@***p* HIRS/mcalib.c
#
# NAME
#   mcalib.c
#
# LOCATION
#   .../hirs/scripts/mstep2/bar/mcalib.c
#
# PURPOSE
#   Intersatellite calibration for Metop HIRS
#
# DESCRIPTION
#   Intersatellite calibration for Metop HIRS based on stepping-function tables
#
# AUTHOR
#   L. Shi
#
# CREATION DATE
#   Dec 2008
#
# COPYRIGHT
#   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC DOMAIN AND
#   THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE.  THEY ARE FURNISHED "AS IS." THE 
#   AUTHORS, THE UNITED STATES GOVERNMENT, ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES, 
#   AND AGENTS MAKE NO WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE 
#   SOFTWARE AND DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
#   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL SUPPORT 
#   TO USERS.
#
# MODIFICATION HISTORY
#   May 2010 - D. Wunder put in robodoc format
#
# INPUTS
#   HIRS.$SATID.Y$YY.*.LC ... limb-corrected HIRS data
#   step.N??.N??.CH??     ... Stepping-function table for NOAA satellites
#   step.N??.M02.CH??     ... Stepping-function table for N17-M02
#
# OUTPUTS
#   new.dat  ...  Intersatellite calibrated HIRS Tb
#
# EXTERNALS
#   None.
#
# TODO
#   n/a
#
# LANGUAGE
#   C
#
#@*****
#---------------------------------------------------------------------------------
*/

#include <stdio.h>
#include <malloc.h>
#include<stdlib.h>
#include <math.h>

#define nbin 200
#define nch 20 // channel number in input HIRS data
#define nsat 11
#define bin 2

main(argc, argv)
     int argc;
     char **argv;
{
  FILE       *ifp,*ifpbin;                /* Input file pointer */
  FILE       *ofp;
  int        n,i,j,k,m,count;
  float      tch[nch],tlc[nch],tnew[nch];
  float      sec,lon,lat,zen,alt;
  int        line,posi;
  int        i1;
  float      f1,f2;
  char       s[100],stepname[17];
  int        sat1[nch],sat2[nch],ch,sat;
  float      diff[nbin][nch][nsat],tmptbin,tmptbin2,tmphalf,oldhalf;
  int        tbin[nbin][nch][nsat],num[nch][nsat];
  int        s1,s2;
  float      tbinhalf;

  tbinhalf = bin/2.0;

  ifp = fopen(argv[1],"r");
  ofp = fopen("new.dat","w");

  sscanf(argv[1], "%6c%2d",s,&sat);

  for (n=0; n<nsat; n++) {
    if (n < 7)
      s1 = n+6;
    else
      s1 = n+7;
    s2 = s1+1;
    if (s1==12)
      s2 = 14;

    for (k=0; k<12; k++) {
      if (s1 == 17)
	sprintf(stepname,"%s%2.2d","step.N17.M02.CH",k+1);
      else
	sprintf(stepname,"%s%2.2d%s%2.2d%s%2.2d",
		"step.N",s1,".N",s2,".CH",k+1);
      ifpbin = fopen(stepname,"r");
      i=0;
      while (fscanf(ifpbin,"%d%d%f",&tbin[i][k][n],&i1,&diff[i][k][n]) != -1) {
        i++;
      }
      close(ifpbin);
      num[k][n] = i-1;
    }
  }

  count = 0;

  while (fscanf(ifp, "%s%f%f%f%f%f%d%d",
                  s,&sec,&lon,&lat,&zen,&alt,&line,&posi) != -1) {
    for (k=0; k<19; k++) {
      fscanf(ifp, "%s%d%f%f", s,&i1,&tch[k],&tlc[k]);
      tnew[k]=tlc[k];
    }
    fscanf(ifp, "%s%d%f", s,&i1,&tlc[19]);

    if(tlc[19] < 1.)
      tlc[19] = tlc[19]*100.;
    else
      tlc[19] = -99.99;
    tnew[19]=tlc[19];
    count++;

    // For sat before N12
    s1 = sat;
    while (s1 < 12 && s1 >= 4) {
      n = s1-6;
      for (k=0; k<12; k++) {
        if(tlc[k] > 0) {
	  if (tnew[k] <= tbin[0][k][n])
                tnew[k] = tnew[k] - diff[0][k][n];
	  else if (tnew[k] >= tbin[num[k][n]][k][n]-tbinhalf)
              tnew[k] = tnew[k] - diff[num[k][n]][k][n];
	  else {
            for (i=0; i<num[k][n]; i++) {
              if (tnew[k] >= tbin[i][k][n]-tbinhalf 
		  && tnew[k] < tbin[i][k][n]+tbinhalf) {
                tnew[k] = tnew[k] - diff[i][k][n];
	        i = nbin;
	      }
	      else {
	      if (tbin[i+1][k][n] - tbin[i][k][n] > bin && 
                  tnew[k] >= tbin[i][k][n]+tbinhalf && 
		  tnew[k] < tbin[i+1][k][n]-tbinhalf) {
                tnew[k] = tnew[k] - (diff[i+1][k][n]+diff[i][k][n])/2.;
		i = nbin;
	      }
	      }
	    }
	  }
	}
        else
          tnew[k] = -99.99;
      }
      s1++;
    }
    // For sat after N12
    s2 = sat;
    if (s2 == 2)
      s2 = 18;
    while (s2 > 12) {
      n = s2-8;
      for (k=0; k<12; k++) {
        if(tlc[k] > 0) {
	  tmptbin = tbin[num[k][n]-1][k][n] - diff[num[k][n]-1][k][n];
	  tmptbin2 = tbin[num[k][n]][k][n] - diff[num[k][n]][k][n];
	  tmphalf = (tmptbin2-tmptbin)*0.5;
	  if (tnew[k] <= tbin[0][k][n]-diff[0][k][n])
                tnew[k] = tnew[k] + diff[0][k][n];
	  else if (tnew[k] >= 
		  tbin[num[k][n]][k][n]-diff[num[k][n]][k][n]-tmphalf)
                tnew[k] = tnew[k] + diff[num[k][n]][k][n];
	  else {
	    tmphalf=1.0;
            for (i=0; i<num[k][n]; i++) {
	      oldhalf=tmphalf;
	      tmptbin = tbin[i][k][n] - diff[i][k][n];
	      tmptbin2 = tbin[i+1][k][n] - diff[i+1][k][n];
	      tmphalf = (tmptbin2-tmptbin)/2.0;
              if (tnew[k] >= tmptbin-oldhalf
		  && tnew[k] < tmptbin+tmphalf
		  && tbin[i+1][k][n] - tbin[i][k][n] == bin) {
                tnew[k] = tnew[k] + diff[i][k][n];
		i = nbin;
	      }
	      else {
	      if (tbin[i+1][k][n] - tbin[i][k][n] > bin && 
                  tnew[k] >= tbin[i][k][n]+tmphalf && 
		  tnew[k] < tbin[i+1][k][n]-tmphalf*0.75) {
                tnew[k] = tnew[k] - (diff[i+1][k][n]+diff[i][k][n])/2.;
		i = nbin;
	      }
	      }
	    }
	  }
	}
        else
          tnew[k] = -99.99;
    }
      s2--;
      if (s2 == 13)
	s2--;
    }

    //For overshooting clouds, the limb-correction peoduces error(>270K)
    if (tnew[11] < 270. && tnew[11] > 180.) {
    fprintf(ofp, "%6d %8.2f %6.2f %6.2f %5.2f %4.0f %4d %2d\n",
          count,sec,lon,lat,zen,alt,line,posi);
    for (k=0; k<12; k++)
      fprintf(ofp,"%2d %6.2f %6.2f\n",k+1,tlc[k],tnew[k]);
    fprintf(ofp,"\n");
    }
  }

  close(ofp);
  printf("count=%d\n", count);

}
