#! /bin/csh
#--------------------------------------------------------------------------------
#@***p* HIRS/runmcalib.csh
#
# NAME
#   runmcalib.csh
#
# LOCATION
#   .../hirs/scripts/mstep2/runmcalib.csh
#
# PURPOSE
#   Intercalibration for METOP HIRS
#
# DESCRIPTION
#   Run .../hirs/scripts/mstep2/bar/mcalib.c
#
# AUTHOR
#   L. Shi
#
# CREATION DATE
#   Dec  2008
#
# COPYRIGHT
#   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC DOMAIN AND
#   THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE.  THEY ARE FURNISHED "AS IS." THE 
#   AUTHORS, THE UNITED STATES GOVERNMENT, ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES, 
#   AND AGENTS MAKE NO WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE 
#   SOFTWARE AND DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
#   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL SUPPORT 
#   TO USERS.
#
# MODIFICATION HISTORY
#   May 2010 - D. Wunder put in robodoc format
#
# INPUTS
#   SATID = satellite ID
#
# OUTPUTS
#   HIRS.$SATID.Y$yy.D$ddd.BN12 ... Intersatellite calibrated to N12
#
# EXTERNALS
#   mcalib.c
#
# TODO
#   n/a
#
# LANGUAGE
#   C
#
#@*****
#---------------------------------------------------------------------------------

# Script for running mcalib.c
# Inter-calibration Metop HIRS

#set satnum = (11 10 09 08 07 06)
set satnum = (02)
foreach SAT ($satnum)
if ($SAT == 02) then
  set SATID = M$SAT
else
  set SATID = N$SAT
endif

set DIRDATA = ${hirs_lc_dir}/LC_$SATID

if (! -d ${hirs_step2__dir}/hirsintercalib/BN12_$SATID) \
  mkdir ${hirs_step2_dir}/hirsintercalib/BN12_$SATID
set DIROUT = ${hirs_step2_dir}/intercalib/BN12_$SATID

if (! -d ${hirs_step2_dir}/tmp_$SATID) mkdir ${hirs_step2_dir}/tmp_$SATID
set WORK = ${hirs_step2_dir}/tmp_$SATID
cp ${hirs_SCRIPT_DIR}/mstep2/bar/step.N* $WORK
cp ${hirs_SCRIPT_DIR}/mstep2/bar/mcalib $WORK

@ year = 2006
while ($year <= 2009)
  set yy = `echo $year | cut -c3-4`
  cd $WORK
  @ jday = 1
  while ($jday <= 366)
    set ddd = `printf "%03d" $jday`
    set FILE = HIRS.$SATID.Y$yy.D$ddd.LC
    cd $DIRDATA
    if (-f $FILE) then
      echo $FILE
      cp $DIRDATA/$FILE $WORK
      cd $WORK
      $WORK/mcalib HIRS.$SATID.Y$yy.D$ddd.LC
      mv new.dat $DIROUT/HIRS.$SATID.Y$yy.D$ddd.BN12
      rm HIRS.$SATID.Y$yy.D$ddd.LC
    endif
    @ jday++
  end
  @ year++
end 
cd ${hirs_DAT_DIR}
rm -rf $WORK
    
end
    
exit 1
