#! /bin/csh
#--------------------------------------------------------------------------------
#@***p* HIRS/runregiontb.csh
#
# NAME
#   runregiontb.csh
#
# LOCATION
#   .../hirs/scripts/mstep2/runregiontb.csh
#
# PURPOSE
#   Put together monthly means from several satellites for a lat/lon region
#
# DESCRIPTION
#   Run regiontb_m2.c
#
# AUTHOR
#   L. Shi
#
# CREATION DATE
#   Dec 2008
#
# COPYRIGHT
#   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC DOMAIN AND
#   THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE.  THEY ARE FURNISHED "AS IS." THE 
#   AUTHORS, THE UNITED STATES GOVERNMENT, ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES, 
#   AND AGENTS MAKE NO WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE 
#   SOFTWARE AND DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
#   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL SUPPORT 
#   TO USERS.
#
# MODIFICATION HISTORY
#   May 2010 - D. Wunder put in robodoc format
#
# INPUTS
#   year = two digit year
#
# OUTPUTS
#   HIRS.SATS.TB.ALLCH.24  ... zonal mean for channel 1-12
#   HIRS.SATS.TB.REGION.24 ... zonal mean for channel 12 only
#
# EXTERNALS
#   regiontb_m2.c
#
# TODO
#   n/a
#
# LANGUAGE
#   C-Shell
#
#@*****
#---------------------------------------------------------------------------------


set INDIR = ${hirs_step2_dir}/BN12tbgridmonthly
set OUTDIR = ${hirs_step2_dir}/region
set WORKDIR = ${hirs_SCRIPT_DIR}/mstep2

set TIME = '24'
@ year = 78

\rm $OUTDIR/HIRS.*.TB.*.$TIME

while ($year <= 109)
  if ($year < 100) then
    @ yy = $year
  else
    @ y = $year - 100
    set yy = 0$y
  endif
  echo $yy
  cd $INDIR
  echo `ls HIRS.*.Y$yy.MG.TB.$TIME`
  set FILES = (`ls HIRS.*.Y$yy.MG.TB.$TIME`)
  cp $FILES $WORKDIR
  cd $WORKDIR
  $WORKDIR/regiontb_m2 $FILES

  cat allch.dat >> $OUTDIR/HIRS.SATS.TB.ALLCH.$TIME
  cat meansats.dat >> $OUTDIR/HIRS.SATS.TB.REGION.$TIME
  rm $FILES

  @ year++
end

exit 1
