#! /bin/csh
#--------------------------------------------------------------------------------
#@***p* HIRS/runtbbsatdaily2000.csh
#
# NAME
#   runtbbsatdaily2000.csh
#
# LOCATION
#   .../hirs/scripts/mstep2/runtbbsatdaily2000.csh
#
# PURPOSE
#   Map daily swath HIRS channel data to global grid
#
# DESCRIPTION
#   Daily gridding of HIRS ch1-12 from clear-sky swath ch1-12 data to 2.5x2.5 
#   lat/lon grids
#
# AUTHOR
#   L. Shi
#
# CREATION DATE
#   Dec 2008
#
# COPYRIGHT
#   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC DOMAIN AND
#   THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE.  THEY ARE FURNISHED "AS IS." THE 
#   AUTHORS, THE UNITED STATES GOVERNMENT, ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES, 
#   AND AGENTS MAKE NO WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE 
#   SOFTWARE AND DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
#   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL SUPPORT 
#   TO USERS.
#
# MODIFICATION HISTORY
#   May 2010 - D. Wunder put in robodoc format
#
# INPUTS
#   SATID = satellite ID
#   YY    = two digit year
#
# OUTPUTS
#   HIRS.$SATID.Y$YY.TB24 ... 24-hour daily gridded data.
#
# EXTERNALS
#   None
#
# TODO
#   n/a
#
# LANGUAGE
#   C-Shell
#
#@*****
#---------------------------------------------------------------------------------


if ($#argv <= 1) then
  echo "Usage: $0 satellite_id 2-digit-year (e.g. tbdaily.csh M02 09)"
  exit 0
endif

set SATID = $argv[1]
set YY = $argv[2]

set TIME = '24'
set DIRDATA = ${hirs_step2_dir}/intercalib/BN12_$SATID
set OUTDIR = ${hirs_step2_dir}/BN12tbgriddaily
set WORKDIR = ${hirs_SCRIPT_DIR}/mstep2

cd $DIRDATA
rm *.TB$TIME
foreach i ( `ls HIRS.$SATID.Y$YY.*.BN12` )
  echo $i

  set SATNUM = `echo $i | cut -c7-8`
  set YEAR = `echo $i | cut -c11-12`
  set DAY = `echo $i | cut -c15-17`

#  if ($YEAR > 70) then
#    @ YYYY = 1900 + $YEAR
#  else
#    @ YYYY = 2000 + $YEAR
#  endif
  echo $SATNUM 20$YEAR $DAY
  echo $SATNUM 20$YEAR $DAY | cat >> HIRS.$SATID.Y$YEAR.TB$TIME
#  $WORKDIR/tbbsatdaily$TIME $i $DAY
  $WORKDIR/tbbsatdaily$TIME $i $DAY 20$YEAR
  cat tgrid.dat >> HIRS.$SATID.Y$YEAR.TB$TIME
end

mv HIRS.*.TB$TIME $OUTDIR
rm $DIRDATA/tgrid*.dat

exit 1
