#! /bin/csh
#--------------------------------------------------------------------------------
#@***p* HIRS/runtbmonthly.csh
#
# NAME
#   runtbmonthly.csh
#
# LOCATION
#   .../hirs/scripts/mstep2/runtbmonthly.csh
#
# PURPOSE
#   Calculate monthly from daily data for the entire series of one satellite
#
# DESCRIPTION
#   Run tbmonthly.c (Compute monthly grid and global mean Tb based on daily gridded data).
#
# AUTHOR
#   L. Shi
#
# CREATION DATE
#   Dec 2008
#
# COPYRIGHT
#   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC DOMAIN AND
#   THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE.  THEY ARE FURNISHED "AS IS." THE 
#   AUTHORS, THE UNITED STATES GOVERNMENT, ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES, 
#   AND AGENTS MAKE NO WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE 
#   SOFTWARE AND DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
#   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL SUPPORT 
#   TO USERS.
#
# MODIFICATION HISTORY
#   May 2010 - D. Wunder put in robodoc format
#
# INPUTS
#   SATID = satellite ID
#   YY    = two digit year
#
# OUTPUTS
#   HIRS.$SATID.MS.TB.24     ... time series of global mean Tb
#   HIRS.$SATID.Y??.MG.TB.24 ... gridded monthly mean Tb
#
# EXTERNALS
#   tbmonthly.c
#
# TODO
#   n/a
#
# LANGUAGE
#   C-Shell
#
#@*****
#---------------------------------------------------------------------------------


if ($#argv <= 1) then
  echo "Usage: $0 satellite_id 2-digit-year (e.g. tbdaily.csh M02 09)"
  exit 0
endif

set SATID = $argv[1]
set YY = $argv[2]

set DIRDATA = ${hirs_step2_dir}/BN12tbgriddaily
set OUTDIR = ${hirs_step2_dir}/BN12tbgridmonthly
set WORKDIR = ${hirs_SCRIPT_DIR}/mstep2

@ itime = 24
while ($itime <= 24)
set  TIME = `printf "%02d" $itime`
echo $TIME

cd $DIRDATA
\rm HIRS.$SATID.MS.TB.$TIME
\rm HIRS.$SATID.MG.TB.$TIME

foreach i ( `ls HIRS.$SATID.Y$YY.TB$TIME` )
echo $i

set YEAR = `echo $i | cut -c11-12`

$WORKDIR/tbmonthly $i
cat gmean.dat >> HIRS.$SATID.MS.TB.$TIME
cat mean.dat >> HIRS.$SATID.Y$YEAR.MG.TB.$TIME

end

mv HIRS.$SATID.MS.TB.$TIME $OUTDIR
mv HIRS.$SATID.Y??.MG.TB.$TIME $OUTDIR
rm gmean.dat
rm mean.dat

@ itime+=3
  
end

exit 1
