/* tbbsatdaily.c */
/*
#--------------------------------------------------------------------------------
#@***p* HIRS/tbbsatdaily.c
#
# NAME
#   tbbsatdaily.c
#
# LOCATION
#   .../hirs/scripts/mstep2/tbbsatdaily.c
#
# PURPOSE
#   Daily gridding of HIRS ch1-12 from clear-sky swath ch1-12 data
#
# DESCRIPTION
#   Daily gridding of HIRS ch1-12 from clear-sky swath ch1-12 data to 2.5x2.5 
#   lat/lon grids
#
# AUTHOR
#   L. Shi
#
# CREATION DATE
#   Dec 2008
#
# COPYRIGHT
#   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC DOMAIN AND
#   THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE.  THEY ARE FURNISHED "AS IS." THE 
#   AUTHORS, THE UNITED STATES GOVERNMENT, ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES, 
#   AND AGENTS MAKE NO WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE 
#   SOFTWARE AND DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
#   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL SUPPORT 
#   TO USERS.
#
# MODIFICATION HISTORY
#   May 2010 - D. Wunder put in robodoc format
#
# INPUTS
#   HIRS.$SATID.Y$yy.D$ddd.BN12 ... Intersatellite calibrated to N12
#
# OUTPUTS
#   tgrid.dat ... gridded data
#
# EXTERNALS
#   None
#
# TODO
#   n/a
#
# LANGUAGE
#   C
#
#@*****
#---------------------------------------------------------------------------------
*/


#include <stdio.h>
#include <malloc.h>
#include <stdlib.h>
#include <math.h>
#include <netcdf.h>

#define nlon 144
#define nlat 72
//largest total observed:158328. Setting of 180000 caused segmentation fault
#define total 160000
#define ch 12

//NetCDF variables
//define NC_FILE_NAME "nc_3D_test.nc"

#define NDIMS 3
//#define NLAT 72
//#define NLON 144
//#define NCHAN 12
#define NTIME 366

#define LAT_NAME "latitude"
#define LON_NAME "longitude"
#define CHAN_NAME "channel"
#define DEGREES_EAST "degrees_east"
#define DEGREES_NORTH "degrees_north"
#define TIME_NAME "time"
#define BT_NAME "brightness_temperature"

#define UNITS "units"
#define LAT_UNITS "degrees_north"
#define LON_UNITS "degree_east"
#define BT_UNITS "degrees_kelvin"

#define ERRCODE 2
#define ERR(e) {printf("Error: %s\n", nc_strerror(e)); exit(ERRCODE);}

//test values
#define SAMPLE_BT 900



main(argc, argv)
     int argc;
     char **argv;
{
  FILE       *ifp;                /* Input file pointer                */
  FILE       *ofp;
  int        n,i,j,k;
  float      tch,tlc[ch][total];
  int        missing,num,count;
  char       s[100];
  float sec[total],lon[total],lat[total],zen,alt;
  int line,posi;
  int i1;
  float f1,f2;
  float latgrid,longrid,tgrid[nlat][nlon][12];
  int test,secb,sece;
  int year = atoi(argv[3]);
  char NC_FILE_NAME[100] = "HIRS-CH12_DAYGRD_v01r01_";
  strcat(NC_FILE_NAME, argv[3]);  
  strcat(NC_FILE_NAME, ".nc");  
  
  /*IDs for the NetCDF file, dimensions, and variables. */
  int ncid, lat_dimid, lon_dimid, chan_dimid, time_dimid, rec_dimid;
  int lat_varid, lon_varid, chan_varid, time_varid, rec_varid;
  int dimids[NDIMS];
  size_t rec_start[NDIMS], rec_count[NDIMS];
  size_t rec_index[NDIMS];
  float bt_out[nlat][nlon][NTIME];
  float lats[nlat], lons[nlon];
  //int lat, lon, chan, day, i=0;
  int retval;
  
  retval = nc_open(NC_FILE_NAME, NC_WRITE, &ncid);
  //printf("retval:%d\n", retval);  
  //printf("nc file name:%s\n", NC_FILE_NAME);  
  if(retval != NC_NOERR){ //no existing NetCDF file, create a new one
    //ERR(retval);

    /*Do some NetCDF setup: dimension and variables*/
    if ((retval = nc_create(NC_FILE_NAME, NC_NOCLOBBER, &ncid)))
      ERR(retval);


    if ((retval = nc_def_dim(ncid, LAT_NAME, nlat, &lat_dimid)))
      ERR(retval);
    if ((retval = nc_def_dim(ncid, LON_NAME, nlon, &lon_dimid)))
      ERR(retval);
    if ((retval = nc_def_dim(ncid, TIME_NAME, NTIME, &time_dimid)))
      ERR(retval);
    if ((retval = nc_def_dim(ncid, BT_NAME, 1000.0, &rec_dimid)))
      ERR(retval);

    if ((retval = nc_def_var(ncid, LAT_NAME, NC_FLOAT, 1, &lat_dimid, 
        &lat_varid)))
      ERR(retval);
    if ((retval = nc_def_var(ncid, LON_NAME, NC_FLOAT, 1, &lon_dimid,
        &lon_varid)))
      ERR(retval);
  
    dimids[0] = time_dimid;
    dimids[1] = lat_dimid;
    dimids[2] = lon_dimid;

    if ((retval = nc_def_var(ncid, BT_NAME, NC_FLOAT, NDIMS, 
        dimids, &rec_varid)))
      ERR(retval);

    if ((retval = nc_put_att_text(ncid, rec_varid, UNITS, 
        strlen(BT_UNITS), BT_UNITS)))
      ERR(retval);

    /*End define mode*/
    if ((retval = nc_enddef(ncid)))
      ERR(retval);
   
    /*Get the lat/lon grid ticks into arrays for NetCDF*/
    latgrid = -88.75;
    for(i=0; i<nlat; i++){
      lats[i]=latgrid;
      latgrid += 2.5;
    }

    longrid = 1.25;
    for(i=0; i<nlon; i++){
      lons[i]=longrid;
      longrid += 2.5;
    }

    if ((retval = nc_put_var_float(ncid, lat_varid, &lats[0])))
      ERR(retval);
    if ((retval = nc_put_var_float(ncid, lon_varid, &lons[0])))
      ERR(retval);
  }
  else{
    if ((retval = nc_inq_varid(ncid, BT_NAME, &rec_varid)))
      ERR(retval);
  }

  int jday = atoi(argv[2]);

  /* 3h=10800s;6h=21600;9h=32400;12h=43200;
     15h=54000;18h=64800;21h=75600;24h=86400s */
  secb = 0;
  sece = 86400;

  ifp = fopen(argv[1],"r");
  ofp = fopen("tgrid.dat","w");

  count = 0;
  //read in the data from the source file
  for (n=0; n<total; n++) {
    test=fscanf(ifp, "%s%f%f%f%f%f%d%d", 
		s,&sec[n],&lon[n],&lat[n],&zen,&alt,&line,&posi);
    if (test == -1)
      goto endofdata;

    for (k=0; k<ch; k++) {
      fscanf(ifp, "%d%f%f", &i1,&tch,&tlc[k][n]);
    }
    count++;
  }
 endofdata: printf("count=%d\n", count);

  /*NetCDF block write variable
  rec_count[0] = 1;
  rec_count[1] = 1;
  rec_count[2] = 1;
  rec_start[1] = 0;
  rec_start[2] = 0;
*/

  for (i=0; i<nlat; i++){
    for (j=0; j<nlon; j++){
      for (k=0; k<ch; k++){
	tgrid[i][j][k] = 0.0;
      }
    }
  }

  latgrid = -88.75-2.5;
  for (i=0; i<nlat; i++) {
    latgrid = latgrid + 2.5;
    longrid = 1.25-2.5;
    for (j=0; j<nlon; j++) {
      longrid = longrid + 2.5;
      num=0;
      for (n=0; n<count; n++) {
	if(fabs(lat[n]-latgrid)<1.25 && fabs(lon[n]-longrid)<1.25
	   && sec[n] >= secb && sec[n] < sece) {
	  for (k=0; k<12; k++) {
	    tgrid[i][j][k] = tgrid[i][j][k] + tlc[k][n];
	  }
	  num++;
	}
      }
      if (num > 0)
	for (k=0; k<12; k++)
	  tgrid[i][j][k] = tgrid[i][j][k] / num;
      else
	for (k=0; k<ch; k++)
	  tgrid[i][j][k] = 999;
    } /* end j loop */
  } /* end i loop */


  for (k=0; k<ch; k++){
    for (i=0; i<nlat; i++) {
      for (j=0; j<nlon; j++){
	fprintf(ofp," %6.2f", tgrid[i][j][k]);
        if (k == 11){
          //rec_start[0] = jday;
          //if ((retval = nc_put_vara_float(ncid, rec_varid, rec_start, rec_count,
          //    &bt_out[i][j][jday])))
          //printf("%d,%d,%d: %6.2f \n", jday, i, j, tgrid[i][j][k]); 
          rec_index[0] = jday;
          rec_index[1] = i;
          rec_index[2] = j; 
          
          if ((retval = nc_put_var1_float(ncid, rec_varid, rec_index, &tgrid[i][j][k])))
            ERR(retval);
          //printf("ret:%d\n", retval);
        }
      }
      fprintf(ofp,"\n");
    }
  }

  fclose(ifp);
  fclose(ofp);
  if ((retval = nc_close(ncid)))
    ERR(retval);
}

