! HIRS Level 1C Data Set structure file
! Base on hrs1c.h file from AAPP V1.0
!
! hrs1c.h history
!
! History:
! Version    Date     Comment
!
!  1.0      2/2/96  Original code. Conforms to 1C format vn1.7 (R.J.Renshaw)
!  1.1     12/12/96 Updated to 1C format vn1.8
!                   'WMO satellite id' now just NOAA sat id
!                   bit 0 (hrs1c_dataqual) now set if all channels missing
!                   Calibration flagword deleted
!  1.2     10/03/98 1C format vn1.9  - add instrument temperature
!
! Structure file created by Darren Jackson on 12/7/98
!
      integer       HnChan
         parameter  (HnChan=20)   ! number of HIRS channels
      integer       HnFovs
         parameter  (HnFovs=56)   ! number of HIRS Fovs
      integer       array_size_hrs1c     ! Length of array
         parameter (array_size_hrs1c = 1664) !  Length of array
 
!
!###########################################################################
!
!               HIRS HEADER RECORD
!
!###########################################################################
!
      structure /hrs1c_hed/

      character*3  site       !dataset creation site ID
      character*1  cfill1     !filler
      character*3  bsite      !creation site for original 1B data
      character*1  cfill2     !filler
      integer*4    versnb     !level 1c format version number
      integer*4    versyr     !level 1c format version year
      integer*4    versdy     !level 1c format version day of year
      integer*4    hdrcnt     !count of header records in this data set
      integer*4    satid      !satellite id (e.g. 14 for NOAA-14)
      integer*4    instrument !instrument code
!                                      (5=HIRS; 6=MSU; 10=AMSU-A; 11=AMSU-B)
      integer*4    satht      !nominal satellite altitude, km*10
      integer*4    period     !nominal orbit period (seconds)
      integer*4    startorbit !orbit number (at start of file)
      integer*4    startdatayr!start of data set year
      integer*4    startdatady!start of data set day of the year
      integer*4    startdatatime !start of data set UTC time of day (ms)
      integer*4    endorbit   !orbit number (at end of file)
      integer*4    enddatayr  !end of data set year
      integer*4    enddatady  !end of data set day of the year
      integer*4    enddatatime!end of data set UTC time of day (ms)
      integer*4    scnlin     !count of scan lines in this data set
      integer*4    misscnlin  !count of missing scan lines
      integer*4    spare      !spare

! temperature-radiance conversion coefficients
      integer*4    tempradcnv(3,Hnchan-1)
!                  order of channels = 1,2,3,4,...,18,19
!                  for nochannel = 1 to 19 :
!                      10^6 x (nochannel central wavenumber)
!                      10^6 x (nochannel constant 1)
!                      10^6 x (nochannel constant 2)
!                  (scaling factor for wavenumber changes to 10^5         
!                   for channels 13-19 inclusive)
      integer*4    solfiltirrad
!                  10^6 x (albedo-radiance ch20 solar filtered irradiance,W/m2)
      integer*4    equifiltwidth
!                  10^6 x (albedo-radiance ch 20 equivalent filter width cm^-1)
      integer*4    filler(1584)  !filler

      end structure
      record /hrs1c_hed/ hrs1c_head
!
!##############################################################################
!
!               HIRS DATA RECORD
!
!##############################################################################
!
      structure /hrs1c_dat/

      integer*4   scnlin     !scan line number
      integer*4   scnlinyr   !scan line year
      integer*4   scnlindy   !scan line day of year
      integer*4   scnlintime !scan line UTC time of day in milliseconds
      integer*4   mjfrcnt    !major frame count
      integer*4   qualind    !quality indicator bit field

!                 In all of the following, if the bit is on (= is set to 1)
!                 then the statement is true. Otherwise it is false.
!
!                 general
!
!                 bit 31: do not use scan for product generation
!                 bit 30: time sequence error detected with this scan
!                 bit 29: data gap precedes this scan
!                 bit 28: no calibration
!                 bit 27: no earth location
!                 bit 26: first good time following a clock update
!                 bit 25: instrument status changed with this scan
!                 bit 24-0: spare  <zero fill>
!
      integer*4   scanqual   !scan line quality flags
!                 time problem code
!                 (all bits off implies the scan time is as expected)
!                 bit 31-24: spare   <zero fill>
!                 bit 23: time field is bad but can probably be inferred
!                         from the previous good time
!                 bit 22: time field is bad and can't be inferred
!                         from the previous good time
!                 bit 21: this record starts a sequence that is inconsistent
!                         with previous times (i.e., there is a time
!                         discontinuity). This may or may not be associated
!                         with a spacecraft clock update. (see bit 26 above)
!                 bit 20: start of a sequence that apparently repeats scan
!                         times that have been previously accepted.
!                 bits 19-16: spare
!
!                 calibration problem code
!
!                 (all bits set to 0 indicates normal calibration)
!                  bit 15: scan line was not calibrated because of bad time
!                  bit 14: scan line was calibrated using fewer than the
!                          preferred number of scan lines because of
!                          proximity to start or end of data set or
!                          to a data gap.
!                  bit 13: scan line was not calibrated because of bad or
!                          insufficient PRT data
!                  bit 12: scan line was calibrated but with marginal PRT data
!                  bit 11: some uncalibrated channels of this scan.
!                          See channel indicators.
!                  bit 10: uncalibrated due to instrument mode
!                  bits 9 and 8: spare
!
!                  Earth location problem code
!
!                  (all bits set to 0 implies the Earth location was normal)
!                  bit 7: not Earth located because of bad time
!                  bit 6: Earth location questionable because of questionable
!                         time code (see time problem flags above)
!                  bit 5: Earth location questionable. Only marginal agreement
!                         with reasonableness check.
!                  bit 4: Earth location questionable. Fails reasonableness
!                         check
!                  bit 3-0: spare
!
      integer*4   chanqual(Hnchan)  !quality flag for each channel
!                 with the channels in the order 1,2,3,..,20.
!                 (all bits off implies a good calibration)
!                      bit 31-6: spare
!                      bit  5-0: TBD (to be defined)
      integer*4   instrtemp         !HIRS baseplate temperature (K*100)

      integer*4   spare1(2)         !spare

      integer*4   latlon(2,Hnfovs)!lat/lon in degrees for Hnfovs
!                     first   : 10^4 x (latitude)
!                     second  : 10^4 x (longitude)
      integer*4   angles(4,Hnfovs) !scan angles for Hnfovs
!                     first:    10^2 x (local zenith angle)
!                     second:   10^2 x (local azimuth angle)
!                     third:    10^2 x (solar zenith angle)
!                     fourth:   10^2 x (solar azimuth angle)
      integer*4   scalti !sat altitude above reference ellipsoid, km*10
      integer*4   spare2(2)             !spare

      integer*4   btemps(Hnchan,Hnfovs) !BT data for Hnfovs
!                     10^2 x scene brightness temperature (K) for channels 1-19
!                     10^2 x radiance Wm-2sr-1(cm-1)-1 for channel 20

      integer*4   dataqual(Hnfovs)
!                 quality control word for the data in each field of view:
!                  (all bits off implies acceptable data)
!                  bit 31: spare   <zero fill>
!                  bit 30: set if secondary calibration used
!                  bit 29-21: spare   <zero fill>
!                  bit 20-1: bit n set to 1 if brightness temperature in
!                            channel n is physically unreasonable or has
!                            not been calculated due to calibration  
!                            problems.
!                  bit 0:    set if all channels missing

      integer*4   filler(119)           !filler

      end structure
      record /hrs1c_dat/ hrs1c_data

