c=============================================================================
c@***h*  HIRS/date_to_julian69.f
c*
c* NAME
c*  date_to_julian69.f
c*
c* LOCATION
c*  /crystal/san3/clearsky4/source/date_to_julian69.f
c*
c* PURPOSE
c*  Computes the julian day starting from Jan 1, 1969.
c*
c* DESCRIPTION
c*  Computes the julian day starting from Jan 1, 1969.
c*
c* AUTHOR
c*  Darren Jackson CIRES/ETL
c*
c* CREATION DATE
c*  Apr 2002
c*
c* COPYRIGHT
c*  THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC DOMAIN AND
c*  THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE.  THEY ARE FURNISHED "AS IS." THE 
c*  AUTHORS, THE UNITED STATES GOVERNMENT, ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES, 
c*  AND AGENTS MAKE NO WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE 
c*  SOFTWARE AND DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
c*  THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL SUPPORT 
c*  TO USERS.
c*
c* MODIFICATION HISTORY
c*  Jan 2010 - D. Wunder put in robodoc format
c*
c* INPUTS
c*  name   date type   dimension    description
c*  -------------------------------------------------
c*  iyr4   integer     scalar       4 digit year
c*  mon    integer     scalar       month number (1 if day is day of year)
c*  day    integer     scalar       day number (day of month if mon > 1 or 
c*                                  day of year if mon=1)
c*
c* OUTPUTS
c*  jday69 integer     scalar      julian day from jan 1, 1969
c*
c* EXTERNALS
c*  None
c*
c* TODO
c*  n/a
c*
c* LANGUAGE
c*  Fortran 
c*
c@*****
c===============================================================================
      subroutine date_to_julian69(iyr4,mon,day,jday69)

      IMPLICIT NONE

      INTEGER jday69,iyr4,mon,day
      INTEGER cday0(13),cday1(13)
      INTEGER yeardif,leapdays

      DATA cday0/0,31,59,90,120,151,181,212,243,273,304,334,365/
      DATA cday1/0,31,60,91,121,152,182,213,244,274,305,335,366/

      yeardif  = iyr4 - 1969
      jday69   = yeardif * 365
      leapdays = yeardif / 4
      jday69   = jday69 + leapdays

      if(mon .gt. 1) then
         if((mod(iyr4,4) .eq. 0 .and. mod(iyr4,100) .ne. 0) .or. 
     .        (mod(iyr4,400) .eq. 0)) then
            jday69 = jday69 + cday1(mon) + day
         else
            jday69 = jday69 + cday0(mon) + day
         endif
      else
         jday69 = jday69 + day
      endif

      return
      end
            
