c================================================================================
c@***h*  HIRS/get_grid_files.f
c*
c* NAME
c*  get_grid_files.f
c*
c* LOCATION
c*  /crystal/san3/clearsky4/source/get_grid_files.f
c*
c* PURPOSE
c*  fills grid of TB max/min values constructed from max_grid.f.
c*
c* DESCRIPTION
c*  fills grid of TB max/min values constructed from max_grid.f.
c*
c* AUTHOR
c*  Darren Jackson CIRES/ETL
c*
c* CREATION DATE
c*  Apr 2002
c*
c* COPYRIGHT
c*  THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC DOMAIN AND
c*  THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE.  THEY ARE FURNISHED "AS IS." THE 
c*  AUTHORS, THE UNITED STATES GOVERNMENT, ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES, 
c*  AND AGENTS MAKE NO WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE 
c*  SOFTWARE AND DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
c*  THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL SUPPORT 
c*  TO USERS.
c*
c* MODIFICATION HISTORY
c*  Jan 2010 - D. Wunder put in robodoc format
c*
c* INPUTS
c*  iog..........file number for max/min grid files (int)
c*
c* OUTPUTS
c*  gmxmn........max/min grid data (real)
c*
c* EXTERNALS
c*  hirs1c.inc
c*
c* NOTES
c*  Reads 3 days of data for use in time_constraint.f routine.  Also checks 
c*  all-sky grid box count values.  If number from daily grid file exceeds 50, 
c*  then assume navigation error and assign grid box TBmax with missing data value.
c*
c* LANGUAGE
c*  Fortran 
c*
c@*****
c=================================================================================
      subroutine get_grid_files(iog,gmxmn)

      implicit none

      include   'hirs1c.inc'

      integer   iday,ii,jj,kk,iog(3)
      real      xgrd(nlon,nlat,ntim)
      real      gmxmn(nlon,nlat,ntim,3)
c
c* Read 3 days of max/min grid files
c
      do iday=1,3
         read(iog(iday),rec=1) xgrd    ! read hirs8 max data
         do ii=1,nlon
            do jj=1,nlat
               do kk=1,ntim
                  gmxmn(ii,jj,kk,iday)=xgrd(ii,jj,kk)
               enddo
            enddo
         enddo
c
c* QC check for navigation error
c
         if(iday .eq. 2) then
            read(iog(iday),rec=3) xgrd ! read hirs8 count data
            do ii=1,nlon
               do jj=1,nlat
                  do kk=1,ntim
                     if(xgrd(ii,jj,kk) .gt. 100.) then
                        gmxmn(ii,jj,kk,iday)=missing
                     endif
                  enddo
               enddo
            enddo
         endif

      enddo               

      return
      end
