c===============================================================================
c@***h*  HIRS/gmax_r.f
c*
c* NAME
c*  gmax_r.f
c*
c* LOCATION
c*  /crystal/san3/clearsky4/source/gmax_r.f
c*
c* PURPOSE
c*  Finds the maximum grid point value of input 2D array grid given the
c*  center point indices i0,j0 and the range in both i (irange) and j (jrang).
c*
c* DESCRIPTION
c*  Finds the maximum grid point value of input 2D array grid given the
c*  center point indices i0,j0 and the range in both i (irange) and j (jrang).
c*
c* AUTHOR
c*  Darren Jackson CIRES/ETL
c*
c* CREATION DATE
c*  Apr 2002
c*
c* COPYRIGHT
c*  THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC DOMAIN AND
c*  THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE.  THEY ARE FURNISHED "AS IS." THE 
c*  AUTHORS, THE UNITED STATES GOVERNMENT, ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES, 
c*  AND AGENTS MAKE NO WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE 
c*  SOFTWARE AND DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
c*  THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL SUPPORT 
c*  TO USERS.
c*
c* MODIFICATION HISTORY
c*  Jan 2010 - D. Wunder put in robodoc format
c*
c* INPUTS
c*    name   data type   dimension   description
c*  --------------------------------------------------------------
c*    grid    real         n x m     array of Tb data
c*       n    integer                # of longitude points
c*       m    integer                # of latitude points
c*      i0    integer                longitude index where observation exists
c*      j0    integer                latitude index where observation exists
c*   irang    integer                longitude range (smaller for land, larger for ocean)
c*   jrang    integer                latitude range
c* missing    real                   missing value
c*
c* OUTPUTS
c*    gmax    real                   Maximum Tb in region defined around grid box (i0,j0)
c*
c* EXTERNALS
c*  none
c*
c* LANGUAGE
c*  Fortran 
c*
c@*****
c================================================================================
      subroutine gmax_r(grid,n,m,i0,j0,irang,jrang,missing,gmax)

      implicit none
      
      integer n,m,i0,j0,irang,jrang,inc,jnc,i,j,i2,j2
      real gmax,grid(n,m),missing

      gmax=-999

      inc=int(irang/2)
      jnc=int(jrang/2)

      do j=j0-jnc,j0+jnc
         if(j .lt. 1) then
            j2=1
         elseif(j .gt. m) then
            j2=m
         else
            j2=j
         endif
         do i=i0-inc,i0+inc
            if(i .lt. 1) then
               i2=n-(i0-inc)
            elseif(i .gt. n) then
               i2=(i0+inc)-n
            else
               i2=i
            endif
            if(grid(i2,j2) .ne. missing) gmax=amax1(grid(i2,j2),gmax)
         enddo
      enddo
      return
      end
