c=========================================================================
c@***h*  HIRS/grid_moment_cs2.f
c*
c* NAME
c*  grid_moment_cs2.f
c*
c* LOCATION
c*  /crystal/san3/clearsky4/source/grid_moment_cs2.f
c*
c* PURPOSE
c*  Computes mean and standard deviation from summed arrays.
c*
c* DESCRIPTION
c*  Computes mean and standard deviation from summed arrays.
c*
c* AUTHOR
c*  Darren Jackson CIRES/ETL
c*
c* CREATION DATE
c*  Apr 2002
c*
c* COPYRIGHT
c*  THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC DOMAIN AND
c*  THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE.  THEY ARE FURNISHED "AS IS." THE 
c*  AUTHORS, THE UNITED STATES GOVERNMENT, ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES, 
c*  AND AGENTS MAKE NO WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE 
c*  SOFTWARE AND DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
c*  THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL SUPPORT 
c*  TO USERS.
c*
c* MODIFICATION HISTORY
c*  Jan 2010 - D. Wunder put in robodoc format
c*  Jan 2004 - version 2, takes into account asc/des passes for clear-sky grid data
c*
c* INPUTS
c*   name   data type   dimension   description
c*   ---------------------------------------------------------
c*   nlon   integer     scalar      number of longitude points
c*   nlat   integer     scalar      number of latitude points
c*   sum    real        3D          summed value at given gridpoint
c*   sumsq  real        3D          sum**2 value at given gridpoint.(float)
c*   count  real        3D          total number of points.(Int*4)
c*
c* OUTPUTS
c*   imn    integer*2   3D          mean value
c*   isd    integer*2   3D          standard deviation
c*   ict    integer*2   3D          total number of points
c*
c*   3D = nlon x nlat x nchn
c*
c* EXTERNALS
c*  hirs_grid.inc
c*  iscale.f
c*
c* LANGUAGE
c*  Fortran 
c*
c@*****
c============================================================================
      subroutine grid_moment_cs2(nlon,nlat,sum,sumsq,count,
     .     imn,isd,ict)

      implicit none
      include 'hirs_grid.inc'
      
      integer nlon,nlat,i,j,k

      integer*2 ict(nlon,nlat,node),imn(nlon,nlat,node)
      integer*2 isd(nlon,nlat,node),iscale

      integer count(nlon,nlat,node)
      real sum(nlon,nlat,node),sumsq(nlon,nlat,node),mn,sd,tmp1,tmp2
      real offset_mn,sfactor_mn,offset_sd,sfactor_sd

      do k=1,node
         do j=1,nlat
            do i=1,nlon
               if(count(i,j,k) .gt. 0) then
                  mn=sum(i,j,k)/count(i,j,k)
                  tmp1=sumsq(i,j,k)/count(i,j,k)
                  tmp2=(sum(i,j,k)/count(i,j,k))**2.
                  if(tmp1 .ge. tmp2) then
                     sd=sqrt(tmp1-tmp2)
                  else
                     sd=0.
                  endif
               else
                  mn=imiss
                  sd=imiss
               endif
            
               offset_mn = 100.
               sfactor_mn = 100.
               offset_sd = 0.
               sfactor_sd = 100.

               imn(i,j,k)=iscale(mn,offset_mn,sfactor_mn)
               isd(i,j,k)=iscale(sd,offset_sd,sfactor_sd)
               ict(i,j,k)=count(i,j,k)

            enddo
         enddo
      enddo

      return
      end
