c=================================================================
c
c NAME: ibiref
c
c PURPOSE:  Compute bidirectional reflectance for HIRS channel 20
c           using radiance value
c
c INPUTS:  name    data type    dimension     description
c          -------------------------------------------------------
c          visr     real        scalar        visible radiance W m-2/ster/cm-1
c          month    integer     scalar        month number (1-12)
c          szen     real        scalar        solar zenith angle
c
c OUTPUT:
c          ibiref   integer     scalar        bidirectional reflectance (0-100)
c
c NOTES:
c        Taken from the ITPP 5.20 code
c
c AUTHOR:
c         Darren Jackson CIRES/ETL April 2002
c===================================================================
      integer function ibiref(visr,mon,szen)

c ... version of 30.01.80
c ... scalar arguments ..
      real szen,visr
      integer mon
c ...
c ... local scalars ..
      real b,solcon,cosz
c ...
c ... local arrays ..
      real alfa(12)
c ...
c ... intrinsic functions ..
      intrinsic float,max0
c ...
c ... data statements ..
      data alfa/1.034,1.028,1.018,1.002,.985,.972,.965,.969,.983,.997,
     +     1.016,1.018/
      data solcon/22.407/
c ...
 
      cosz = cosd(szen)
      b = visr / (cosz*solcon*alfa(mon))
      ibiref = nint(b*100.)
      ibiref = max0(ibiref,0)

      return
      end
