c=============================================================================
c@***h*  HIRS/nodalpass.f
c*
c* NAME
c*  nodalpass.f
c*
c* LOCATION
c*  /crystal/san3/clearsky4/source/nodalpass.f
c*
c* PURPOSE
c*  Determines from HIRS scan line data if observations are from ascending
c*  or descending pass.  
c*
c* DESCRIPTION
c*  Determines from HIRS scan line data if observations are from ascending
c*  or descending pass.  
c*
c* AUTHOR
c*  Darren Jackson CIRES/ETL 
c*
c* CREATION DATE
c*  Mar 2001
c*
c* COPYRIGHT
c*  THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC DOMAIN AND
c*  THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE.  THEY ARE FURNISHED "AS IS." THE 
c*  AUTHORS, THE UNITED STATES GOVERNMENT, ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES, 
c*  AND AGENTS MAKE NO WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE 
c*  SOFTWARE AND DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
c*  THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL SUPPORT 
c*  TO USERS.
c*
c* MODIFICATION HISTORY
c*  Jan 2010 - D. Wunder put in robodoc format
c*  Jan 2003 - D. Jackson, Repaired test for observations straddling GM
c*
c* INPUTS
c*  itime.............time in seconds from start of day
c*  xlon..............longitude( 0 to 360)
c*  iline.............line number
c*  nd................Nodal index from previous observation (1 or 2)
c*  prvtime...........previous pixel time stamp
c*  prvlon............previous pixel longitude
c*  prvline...........previous line number
c*  prvnd.............previous node index
c*
c* OUTPUTS
c*  nd .............. 1 = ascending, 2 = descending
c*
c* NOTES
c*   - This code assumes that the input nodal index
c*     is correct value from the previous observation.  The node is
c*     assumed to remain the same until this code changes it.
c*   - Longitude test will allow a very small number of observations
c*     slip through with the wrong nodal index.  This will work if
c*     fine if working with large number of data.
c*
c* LANGUAGE
c*  Fortran 
c*
c@*****
c=============================================================================

      subroutine nodalpass(itime,xlon,iline,nd,prvtime,prvlon,
     .     prvline,prvnd)

      real    xlon,prvlon
      integer iline,prvline,prvnd,isp,prvsp,nd,itime,prvtime
c
c* check node using longitude test.  Only make change in node value if 
c  previous observation is located on the same scan line.
c
      if(iline .eq. prvline) then
c
c*  Only change nodal index if current and previous observation are within 700 seconds.
c
         if(itime-prvtime .lt. 700) then
c
c*  Test for observations straddling GM
c
            if(abs(xlon-prvlon) .gt. 330.) then
c
c*  Difference > 0 is descending, < 0 is ascending
c
               if(xlon-prvlon .gt. 0.) then
                  nd=2
               else
                  nd=1
               endif
c
c* Now for observations not straddling GM
c
            else
c
c* Difference > 0 is ascending, < 0 is descending
c
               if(xlon-prvlon .gt. 0.) then
                  nd=1
               else
                  nd=2
               endif
            endif
         endif
      endif
      
      return
      end
 
