c=============================================================================
c@***h*  HIRS/open_asd.f
c*
c* NAME
c*  open_asd.f
c*
c* LOCATION
c*  /crystal/san3/clearsky4/source/open_asd.f
c*
c* PURPOSE
c*  This routine opens output files for hirs1c.f
c*
c* DESCRIPTION
c*  This routine opens output files for hirs1c.f
c*
c* AUTHOR
c*  Darren Jackson CIRES/ETL 
c*
c* CREATION DATE
c*  Mar 2001
c*
c* COPYRIGHT
c*  THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC DOMAIN AND
c*  THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE.  THEY ARE FURNISHED "AS IS." THE 
c*  AUTHORS, THE UNITED STATES GOVERNMENT, ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES, 
c*  AND AGENTS MAKE NO WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE 
c*  SOFTWARE AND DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
c*  THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL SUPPORT 
c*  TO USERS.
c*
c* MODIFICATION HISTORY
c*  Jan 2010 - D. Wunder put in robodoc format
c*
c* INPUTS
c*  iog..........file number for max/min grid files (int)
c*  ion..........file number for temporary scan line file (int)
c*  satid........satellite character id (character*3)
c*  iyr2..........two digit year (int)
c*  jday.........julian day (int)
c*
c* OUTPUTS
c*  Opens files for hirs1c.f
c*
c* EXTERNALS
c*  hirs1c.inc
c*  recl_parms.inc
c*  julian2.f
c*
c* LANGUAGE
c*  Fortran 
c*
c@*****
c==================================================================

      subroutine open_asd(ion,iog,satid,iyr2,jday)

      implicit none
      include 'hirs1c.inc'
      include 'recl_parms.inc'

      integer   ion,iog,iyr4,iyr2,jday,imn,idy,n
      character satid*3,tmp_path*12
      character dgrid_path*8,dgrid_file*50
      character tmp_file*50

      logical   around      

      data tmp_path/'../tmp_data/'/
      data dgrid_path/'../grid/'/

      if(iyr2 .lt. 69) then
         iyr4=iyr2+2000
      else
         iyr4=iyr2+1900
      endif
      call julian2(jday,iyr4,imn,idy)
c
c*  Open temporary scan line data file
c
      around=.false.
      write(tmp_file,98) 'HIRS.',satid,'.Y',iyr2,'.D',jday,'.V22.AS'
      inquire(file=tmp_path//tmp_file,exist=around)
      if(around) then
         call system("rm "//tmp_path//tmp_file)
      endif
 98   format(a5,a3,a2,i2.2,a2,i3.3,a7)
      open(unit=ion,file=tmp_path//tmp_file,status='unknown',
     .     access='direct',recl=as_rec)
c
c* Open max/min daily grid file
c
      around=.false.
      write(dgrid_file,98) 'HIRS.',satid,'.Y',iyr2,'.D',jday,'.V22.GD'
      inquire(file=dgrid_path//dgrid_file,exist=around)
      if(around) then
         call system("rm "//dgrid_path//dgrid_file)
      endif
      open(unit=iog,file=dgrid_path//dgrid_file,access='direct',
     .     recl=nlon*nlat*ntim*as*4)

      return
      end
