c=============================================================================
c@***h*  HIRS/open_regcoef.f
c*
c* NAME
c*  open_regcoef.f
c*
c* LOCATION
c*  /crystal/san3/clearsky4/source/open_regcoef.f
c*
c* PURPOSE
c*  Opens and reads HIRS limb regression coefficients for computed from
c*  IDL procedure hirs_limb_coef5.pro.  These regression coefficients
c*  do not use the HIRS 13-19 channels are predictors for regression.
c*
c* DESCRIPTION
c*  Opens and reads HIRS limb regression coefficients for computed from
c*  IDL procedure hirs_limb_coef5.pro.  These regression coefficients
c*  do not use the HIRS 13-19 channels are predictors for regression.
c*
c* AUTHOR
c*  Darren Jackson
c*
c* CREATION DATE
c*  Nov 2004
c*
c* COPYRIGHT
c*  THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC DOMAIN AND
c*  THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE.  THEY ARE FURNISHED "AS IS." THE 
c*  AUTHORS, THE UNITED STATES GOVERNMENT, ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES, 
c*  AND AGENTS MAKE NO WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE 
c*  SOFTWARE AND DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
c*  THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL SUPPORT 
c*  TO USERS.
c*
c* MODIFICATION HISTORY
c*  Jan 2010 - D. Wunder put in robodoc format
c*  Feb 2008 - Changed 'hirs_limb_..._n' to 'hirs_limb_..._m' for Mrtop
c*
c* INPUTS
c*  iok..........Regression coefficient files
c*  isat.........Satellite number
c*  chnord.......Regression channel order array
c*  npred........Number of predictors
c*
c* OUTPUTS
c*  rcoef........Regression coefficient array
c*
c* LANGUAGE
c*  Fortran 
c*
c@*****
c=============================================================================
c
c   
c
      subroutine open_regcoef(iok,isat,rcoef,chnord,npred)

      implicit none
      include 'hirs1c.inc'
      include 'datapaths.inc'

      real      rcoef(ncoef,nang,nchn3)
      integer   icoef(ncoef,nang,nchn3)
      integer   chnord(ncoef-1,nang,nchn3),npred(nang,nchn3)
      integer   i,j,k,isat,iok

      character coef_file*16,chnord_file*18,npred_file*17,suffix2*12
      character infile*70,suffix1*8

c      r_path='/home/djackson/clearsky/limb_data/'
      coef_file='hirs_limb_coef_m'
      chnord_file='hirs_limb_chnord_m'
      npred_file='hirs_limb_npred_m'
      suffix1='.lir.dat'
      suffix2='.lon.lir.dat'

c*  Open coefficient file
      write(infile,'(a,a16,i2.2,a12)') r_path,coef_file,isat,suffix2
      open(iok,file=infile,access='direct',recl=ncoef*nang*nchn3*4)
      read(iok,rec=1) icoef
      close(iok)
      do i=1,ncoef
         do j=1,nang
            do k=1,nchn3
C              call swap32(icoef(i,j,k),1)
              rcoef(i,j,k)=icoef(i,j,k)/100000.
            enddo
         enddo
      enddo

c*  Open channel order file
      write(infile,'(a,a18,i2.2,a8)') r_path,chnord_file,isat,suffix1
      open(iok,file=infile,access='direct',recl=(ncoef-1)*nang*nchn3*4)
      read(iok,rec=1) chnord
      close(iok)
C      do i=1,ncoef-1
C         do j=1,nang
C            do k=1,nchn3
C              call swap32(chnord(i,j,k),1)
C            enddo
C         enddo
C      enddo

c*  Open number of predictors file
      write(infile,'(a,a17,i2.2,a8)') r_path,npred_file,isat,suffix1
      open(iok,file=infile,access='direct',recl=nang*nchn3*4)
      read(iok,rec=1) npred
      close(iok)
C      do j=1,nang
C         do k=1,nchn3
C           call swap32(npred(j,k),1)
C         enddo
C      enddo

      return
      end
