c=============================================================================
c@***h*  HIRS/qc_histo.f
c*
c* NAME
c*  qc_histo.f
c*
c* LOCATION
c*  /crystal/san3/clearsky4/source/qc_histo.f
c*
c* PURPOSE
c*  Reads statistics file derived from the orbit mean statistics data.
c*
c* DESCRIPTION
c*  Reads statistics file derived from the orbit mean statistics data.
c*
c* AUTHOR
c*  Darren Jackson CIRES/ETL
c*
c* CREATION DATE
c*  Apr 2002
c*
c* COPYRIGHT
c*  THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC DOMAIN AND
c*  THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE.  THEY ARE FURNISHED "AS IS." THE 
c*  AUTHORS, THE UNITED STATES GOVERNMENT, ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES, 
c*  AND AGENTS MAKE NO WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE 
c*  SOFTWARE AND DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
c*  THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL SUPPORT 
c*  TO USERS.
c*
c* MODIFICATION HISTORY
c*  Jan 2010 - D. Wunder put in robodoc format
c*
c* INPUTS
c*  name   data type   dimension    description
c*  --------------------------------------------
c*  iom    integer     scalar       file number for HIRS histogram stat file
c*
c* OUTPUTS
c*  name   data type   dimension    description
c*  --------------------------------------------
c*  qcmn   integer     4D           mean values
c*  qcsd   integer     4D           standard deviation values
c*  qcct   integer     4D           total number of observations
c*
c* NOTES 
c*  1. Not used in current version (ver 2.2) of processing code
c*  2. These data were computed using IDL procedure *.pro.  These data
c*     are used later in routine horb.f to determine whether the current
c*     data being processed are exceptable.
c*
c* LANGUAGE
c*  Fortran 
c*
c@*****
c================================================================================

      subroutine qc_histo(iom,qcmn,qcsd,qcct)

      implicit none

      include 'hirs1c.inc'

      integer i,j,k,l,iom,qcct(nchn2,nsat,nyr,nmon)
      integer qcmn(nchn2,nsat,nyr,nmon),qcsd(nchn2,nsat,nyr,nmon)

      character hs_file*30,histo_path*13
      logical   around      

      data histo_path/'../misc_data/'/
c
c*  Open HIRS histogram stat file
c
      hs_file='hirs_annual_moments3.dat'
      inquire(file=histo_path//hs_file,exist=around)
      if(.not. around) then
         write(*,*) 'HIRS histogram statistics file does not exist'
         write(*,*) 'Terminate program'
         stop
      else
         open(unit=iom,file=histo_path//hs_file,status='old',
     .        access='direct',form='unformatted',
     .        recl=nchn2*nsat*nyr*nmon*4)
      endif

      read(iom,rec=1) qcmn
      read(iom,rec=2) qcsd
      read(iom,rec=3) qcct
      close(iom)

      do i=1,nchn2
         do j=1,nsat
            do k=1,nyr
               do l=1,nmon
                  call swap32(qcmn(i,j,k,l),1)
                  call swap32(qcsd(i,j,k,l),1)
                  call swap32(qcct(i,j,k,l),1)
               enddo
            enddo
         enddo
      enddo

      return
      end
