c=============================================================================
c@***h*  HIRS/tb_clear.f
c*
c* NAME
c*  tb_clear.f
c*
c* LOCATION
c*  /crystal/san3/clearsky4/source/tb_clear.f
c*
c* PURPOSE
c*  Test used to determine HIRS-8 TB clear-sky value from composite grids.
c*  Performs long-term cloud test for Pathfinder cloud detection.
c*
c* DESCRIPTION
c*  Test used to determine HIRS-8 TB clear-sky value from composite grids.
c*  Performs long-term cloud test for Pathfinder cloud detection.
c*
c* AUTHOR
c*  Darren Jackson CIRES/ETL
c*
c* CREATION DATE
c*  Apr 2002
c*
c* COPYRIGHT
c*  THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC DOMAIN AND
c*  THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE.  THEY ARE FURNISHED "AS IS." THE 
c*  AUTHORS, THE UNITED STATES GOVERNMENT, ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES, 
c*  AND AGENTS MAKE NO WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE 
c*  SOFTWARE AND DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
c*  THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL SUPPORT 
c*  TO USERS.
c*
c* MODIFICATION HISTORY
c*  Jan 2010 - D. Wunder put in robodoc format
c*
c* INPUTS
c*  name     data type  description
c*  --------------------------------------------------------
c*  lmask    byte       land mask id (2=coastal,1=land,0=water)
c*  nclrst   real       # clear short-term clear-sky obs.
c*  nclrlt   real       # clear long-term clear-sky obs.
c*  tavgst   real       Average clear-sky short-term temperature
c*  tavglt   real       Average clear-sky long-term temperature
c*  tmaxst   real       Maximum clear-sky short-term temperature
c*  tmaxlt   real       Maximum clear-sky long-term temperature
c*
c* OUTPUTS
c*  tbclear real       Gives clear-sky temperature using composite statistics
c*  tbid    int*2      Gives method used to arrive at clear-sky temperature
c*                     4 -> Tavg-st
c*                     3 -> Tmax-st - Del2
c*                     2 -> Tavg-lt
c*                     1 -> Tmax-lt - Del3
c*
c* NOTES
c*  Typically the short term statistics (tbid = 4,3) when persistent clouds not
c*  an issue.  Long-term statistics are needed for the persistent cloud regions.
c*  Del2 or Del3 are used for samples with relatively few observations.
c*
c* LANGUAGE
c*  Fortran 
c*
c@*****
c=================================================================================

      subroutine tb_clear(lmask,nclrst,nclrlt,tavgst,tavglt,
     .     tmaxst,tmaxlt,tbclear,tbid)

      implicit none

      byte    lmask
      integer*2 tbid
      real    del1(0:1),del2(0:1),del3(0:1),del4(0:1),nclrstmn,nclrltmn
      real    tavgst,tavglt,tmaxst,tmaxlt,tbclear,nclrst,nclrlt

      data del1/2.0,6.0/   ! from ISCPP paper 
      data del2/2.0,5.0/
      data del3/2.5,8.0/
      data del4/4.0,8.0/
      data nclrstmn/3./
      data nclrltmn/3./

      if(lmask .eq. 2) lmask=1              ! Set coastal regions to land setting

      if((tmaxst .ge. tmaxlt-del1(lmask)) .and. 
     .     (nclrst .ge. nclrstmn)) then
         if(tavgst .ge. tmaxst-del2(lmask)) then
            tbclear=tavgst
            tbid=4
         else
            tbclear=tmaxst-del2(lmask)
            tbid=3
         endif
      else
         if(nclrlt .ge. nclrltmn) then
            if(tavglt .ge. tmaxlt-del3(lmask)) then
               tbclear=tavglt
               tbid=2
            else
               tbclear=tmaxlt-del3(lmask)
               tbid=1
            endif
         else
            tbclear=tmaxlt-del3(lmask)
            tbid=1
         endif
      endif

      return
      end
