c=============================================================================
c@***h*  HIRS/unpack_hirs.f
c*
c* NAME
c*  unpack_hirs.f
c*
c* LOCATION
c*  /crystal/san3/clearsky4/source/unpack_hirs.f
c*
c* PURPOSE
c*  unpacks itpp tovprw5_h data information for one MSU scan line
c*
c* DESCRIPTION
c*  unpacks itpp tovprw5_h data information for one MSU scan line
c*
c* AUTHOR
c*  unk
c*
c* CREATION DATE
c*  unk
c*
c* COPYRIGHT
c*  THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC DOMAIN AND
c*  THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE.  THEY ARE FURNISHED "AS IS." THE 
c*  AUTHORS, THE UNITED STATES GOVERNMENT, ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES, 
c*  AND AGENTS MAKE NO WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE 
c*  SOFTWARE AND DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
c*  THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL SUPPORT 
c*  TO USERS.
c*
c* MODIFICATION HISTORY
c*  Jan 2010 - D. Wunder put in robodoc format
c*
c* INPUTS
c*  l.........................block number                 (int*4)
c*  isat......................satellite number             (int*4)
c*  iou.......................file number index            (int*4)
c*
c* OUTPUTS
c*  xlat(nspot)...............latitude (-90 to 90)         (float)
c*  xlon(nspot)...............longitude (0 to 359.99)      (float)
c*  ispot(nspot)..............scan position                (int*4)
c*  line(nspot)...............line number                  (int*4)
c*  iyr(nspot)................year-1900                    (int*4)
c*  idy(nspot)................julian day                   (int*4)
c*  time(nspot)...............seconds in the day           (float)
c*  tb(nspot,nchn)............TBs                          (float)
c*  szen(nspot)...............solar zenith angle (degrees) (float)
c*  lz(nspot).................local zenith angle (degrees) (float)
c*  alt(nspot)................altitude (km)                (float)
c*  refl(nspot)...............reflectance (HIRS/2 only)    (float)
c*
c* LANGUAGE
c*  Fortran 
c*
c@*****
c=========================================================================

      subroutine unpack_hirs(l,isat,iou,ispot,line,time,
     .     xlat,xlon,szen,alt,lz,tb,refl)

      implicit none
      include 'hirs1c.inc'
      include 'aapp1c.inc'
      integer indata(trec),n,m,isp,line(nspot),ispot(nspot)
      integer iou,l,isat

      real    xlat(nspot),xlon(nspot),tb(nspot,nchn),time(nspot)
      real    alt(nspot),lz(nspot),szen(nspot),refl(nspot),lza

      external lza
c
c HIRS/2 cases
c
c      if(isat .le. 14) then
      if(isat .ge. 5 .and. isat .le. 14) then
         read(iou,rec=l+1,err=99) indata
         do m=1,nspot
            isp=(m-1)*nlen
            xlat(m)=indata(1+isp)/100.
            xlon(m)=indata(2+isp)/100.
            szen(m)=indata(3+isp)/100.
            do n=1,nchn2
               tb(m,n)=indata(3+isp+n)/100.
            enddo
            refl(m)=indata(23+isp)/100.
            write(*,*) '---'
            write(*,*) refl(m)
            time(m)=indata(24+isp)/64.
            alt(m)=indata(25+isp)/1000.
            line(m)=int(indata(26+isp)/100.)
            ispot(m)=mod(indata(26+isp),100)
            lz(m)=lza(alt(m),ispot(m))
            if(xlon(m) .lt. 0.) xlon(m)=360.+ xlon(m)
         enddo
c
c HIRS/3 case
c
      else
         read(iou,rec=l+1,err=99) hrs1c_data
c         write(*,*)
c         write(*,*) iou,l
c         write(*,*) '--------------'
         do m=1,nspot
            xlat(m)=hrs1c_data.latlon(1,m)/10000.
            xlon(m)=hrs1c_data.latlon(2,m)/10000.
            szen(m)=hrs1c_data.angles(3,m)/100.
            lz(m)=hrs1c_data.angles(1,m)/100.
            do n=1,nchn2
               tb(m,n)=hrs1c_data.btemps(n,m)/100.
               if(tb(m,n) .lt. -999.) tb(m,n) = missing
            enddo
c            if(hrs1c_data.btemps(20,m) .gt. -999999)then
c              write(*,*) 'tb(1,',m,'): ',tb(1,m)
c              write(*,*) 'tb(19,',m,'):',tb(19,m)
c              write(*,*) 'refl(',m,l,'): ',hrs1c_data.btemps(20,m)/100.
c            endif

c            refl(m)=missing
            refl(m)=hrs1c_data.btemps(20,m)/100.
            time(m)=(hrs1c_data.scnlintime+(100*m))/1000.
            alt(m)=hrs1c_data.scalti/10.
            line(m)=hrs1c_data.scnlin
            ispot(m)=m
            if(xlon(m) .lt. 0.) xlon(m)=360.+ xlon(m)
         enddo
      endif         
      return
 99   write(*,*) 'Error reading HIRS data record'
      stop
      end
